# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags
from .validators import boolean
from .validators.efs import Bursting  # noqa: F401
from .validators.efs import Elastic  # noqa: F401
from .validators.efs import Provisioned  # noqa: F401
from .validators.efs import (
    provisioned_throughput_validator,
    throughput_mode_validator,
    validate_backup_policy,
)


class PosixUser(AWSProperty):
    """
    `PosixUser <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-efs-accesspoint-posixuser.html>`__
    """

    props: PropsDictType = {
        "Gid": (str, True),
        "SecondaryGids": ([str], False),
        "Uid": (str, True),
    }


class CreationInfo(AWSProperty):
    """
    `CreationInfo <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-efs-accesspoint-creationinfo.html>`__
    """

    props: PropsDictType = {
        "OwnerGid": (str, True),
        "OwnerUid": (str, True),
        "Permissions": (str, True),
    }


class RootDirectory(AWSProperty):
    """
    `RootDirectory <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-efs-accesspoint-rootdirectory.html>`__
    """

    props: PropsDictType = {
        "CreationInfo": (CreationInfo, False),
        "Path": (str, False),
    }


class AccessPoint(AWSObject):
    """
    `AccessPoint <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-efs-accesspoint.html>`__
    """

    resource_type = "AWS::EFS::AccessPoint"

    props: PropsDictType = {
        "AccessPointTags": (Tags, False),
        "ClientToken": (str, False),
        "FileSystemId": (str, True),
        "PosixUser": (PosixUser, False),
        "RootDirectory": (RootDirectory, False),
    }


class BackupPolicy(AWSProperty):
    """
    `BackupPolicy <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-efs-filesystem-backuppolicy.html>`__
    """

    props: PropsDictType = {
        "Status": (str, True),
    }

    def validate(self):
        validate_backup_policy(self)


class FileSystemProtection(AWSProperty):
    """
    `FileSystemProtection <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-efs-filesystem-filesystemprotection.html>`__
    """

    props: PropsDictType = {
        "ReplicationOverwriteProtection": (str, False),
    }


class LifecyclePolicy(AWSProperty):
    """
    `LifecyclePolicy <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-efs-filesystem-lifecyclepolicy.html>`__
    """

    props: PropsDictType = {
        "TransitionToArchive": (str, False),
        "TransitionToIA": (str, False),
        "TransitionToPrimaryStorageClass": (str, False),
    }


class ReplicationDestination(AWSProperty):
    """
    `ReplicationDestination <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-efs-filesystem-replicationdestination.html>`__
    """

    props: PropsDictType = {
        "AvailabilityZoneName": (str, False),
        "FileSystemId": (str, False),
        "KmsKeyId": (str, False),
        "Region": (str, False),
    }


class ReplicationConfiguration(AWSProperty):
    """
    `ReplicationConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-efs-filesystem-replicationconfiguration.html>`__
    """

    props: PropsDictType = {
        "Destinations": ([ReplicationDestination], False),
    }


class FileSystem(AWSObject):
    """
    `FileSystem <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-efs-filesystem.html>`__
    """

    resource_type = "AWS::EFS::FileSystem"

    props: PropsDictType = {
        "AvailabilityZoneName": (str, False),
        "BackupPolicy": (BackupPolicy, False),
        "BypassPolicyLockoutSafetyCheck": (boolean, False),
        "Encrypted": (boolean, False),
        "FileSystemPolicy": (dict, False),
        "FileSystemProtection": (FileSystemProtection, False),
        "FileSystemTags": (Tags, False),
        "KmsKeyId": (str, False),
        "LifecyclePolicies": ([LifecyclePolicy], False),
        "PerformanceMode": (str, False),
        "ProvisionedThroughputInMibps": (provisioned_throughput_validator, False),
        "ReplicationConfiguration": (ReplicationConfiguration, False),
        "ThroughputMode": (throughput_mode_validator, False),
    }


class MountTarget(AWSObject):
    """
    `MountTarget <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-efs-mounttarget.html>`__
    """

    resource_type = "AWS::EFS::MountTarget"

    props: PropsDictType = {
        "FileSystemId": (str, True),
        "IpAddress": (str, False),
        "SecurityGroups": ([str], True),
        "SubnetId": (str, True),
    }



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.


def validate_policy_type(policy_type):
    """
    Property: Policy.Type
    """
    valid_types = [
        "AISERVICES_OPT_OUT_POLICY",
        "BACKUP_POLICY",
        "SERVICE_CONTROL_POLICY",
        "TAG_POLICY",
    ]
    if policy_type not in valid_types:
        raise ValueError("Type must be one of: %s" % ", ".join(valid_types))
    return policy_type



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.


from .. import AWSHelperFn, FindInMap, If, Ref, cloudformation
from ..type_defs.compat import Final
from . import boolean, exactly_one, mutually_exclusive

EC2_INSTANCE_LAUNCH: Final = "autoscaling:EC2_INSTANCE_LAUNCH"
EC2_INSTANCE_LAUNCH_ERROR: Final = "autoscaling:EC2_INSTANCE_LAUNCH_ERROR"
EC2_INSTANCE_TERMINATE: Final = "autoscaling:EC2_INSTANCE_TERMINATE"
EC2_INSTANCE_TERMINATE_ERROR: Final = "autoscaling:EC2_INSTANCE_TERMINATE_ERROR"
TEST_NOTIFICATION: Final = "autoscaling:TEST_NOTIFICATION"

# Termination Policy constants
Default: Final = "Default"
OldestInstance: Final = "OldestInstance"
NewestInstance: Final = "NewestInstance"
OldestLaunchConfiguration: Final = "OldestLaunchConfiguration"
OldestLaunchTemplate: Final = "OldestLaunchTemplate"
ClosestToNextInstanceHour: Final = "ClosestToNextInstanceHour"
AllocationStrategy: Final = "AllocationStrategy"


def validate_int_to_str(x):
    """
    Backward compatibility - field was int and now str.
    Property: AutoScalingGroup.MaxSize
    Property: AutoScalingGroup.MinSize
    """

    if isinstance(x, int):
        return str(x)
    if isinstance(x, str):
        return str(int(x))

    raise TypeError(f"Value {x} of type {type(x)} must be either int or str")


class Tag(AWSHelperFn):
    """
    Export:
    """

    def __init__(self, key, value, propogate):
        self.data = {
            "Key": key,
            "Value": value,
            "PropagateAtLaunch": propogate,
        }


class Tags(AWSHelperFn):
    """
    Export:
    """

    defaultPropagateAtLaunch = True
    manyType = [type([]), type(())]

    def __init__(self, **kwargs):
        self.tags = []
        for k, v in sorted(kwargs.items()):
            if type(v) in self.manyType:
                propagate = boolean(v[1])
                v = v[0]
            else:
                propagate = boolean(self.defaultPropagateAtLaunch)
            self.tags.append(
                {
                    "Key": k,
                    "Value": v,
                    "PropagateAtLaunch": propagate,
                }
            )

    # append tags to list
    def __add__(self, newtags):
        newtags.tags = self.tags + newtags.tags
        return newtags

    def to_dict(self):
        return self.tags


def validate_tags_or_list(x):
    """
    Duplicate this since Tags is different from the stock version

    Property: AutoScalingGroup.Tags
    """
    from .. import AWSHelperFn

    if isinstance(x, (AWSHelperFn, Tags, list)):
        return x

    raise ValueError(f"Value {x} of type {type(x)} must be either Tags or list")


class Metadata(AWSHelperFn):
    """
    Export:
    """

    def __init__(self, init, authentication=None):
        self.validate(init, authentication)
        # get keys and values from init and authentication

        # if there's only one data point, then we know its the default
        # cfn-init; where the key is 'config'
        if len(init.data) == 1:
            initKey, initValue = init.data.popitem()
            self.data = {initKey: initValue}
        else:
            self.data = init.data

        if authentication:
            authKey, authValue = authentication.data.popitem()
            self.data[authKey] = authValue

    def validate(self, init, authentication):
        if not isinstance(init, cloudformation.Init):
            raise ValueError("init must be of type cloudformation.Init")

        is_instance = isinstance(authentication, cloudformation.Authentication)
        if authentication and not is_instance:
            raise ValueError(
                "authentication must be of type cloudformation.Authentication"
            )


def validate_launch_template_specification(self):
    """
    Class: LaunchTemplateSpecification
    """
    template_ids = ["LaunchTemplateId", "LaunchTemplateName"]
    exactly_one(self.__class__.__name__, self.properties, template_ids)


def validate_auto_scaling_group(self):
    """
    Class: AutoScalingGroup
    """
    if "UpdatePolicy" in self.resource:
        update_policy = self.resource["UpdatePolicy"]

        if (
            not isinstance(update_policy, AWSHelperFn)
            and "AutoScalingRollingUpdate" in update_policy.properties
        ):
            if not isinstance(update_policy.AutoScalingRollingUpdate, AWSHelperFn):
                rolling_update = update_policy.AutoScalingRollingUpdate

                min_instances = rolling_update.properties.get(
                    "MinInstancesInService", "0"
                )
                is_min_no_check = isinstance(min_instances, (If, FindInMap, Ref))
                is_max_no_check = isinstance(self.MaxSize, (If, FindInMap, Ref))

                if not (is_min_no_check or is_max_no_check):
                    max_count = int(self.MaxSize)
                    min_count = int(min_instances)

                    if min_count >= max_count:
                        raise ValueError(
                            "The UpdatePolicy attribute "
                            "MinInstancesInService must be less than the "
                            "autoscaling group's MaxSize"
                        )

    instance_config_types = [
        "LaunchConfigurationName",
        "LaunchTemplate",
        "InstanceId",
    ]

    mutually_exclusive(self.__class__.__name__, self.properties, instance_config_types)

    availability_zones = self.properties.get("AvailabilityZones")
    vpc_zone_identifier = self.properties.get("VPCZoneIdentifier")
    if not availability_zones and not vpc_zone_identifier:
        raise ValueError(
            "Must specify AvailabilityZones and/or "
            "VPCZoneIdentifier: http://docs.aws.amazon.com/A"
            "WSCloudFormation/latest/UserGuide/aws-propertie"
            "s-as-group.html#cfn-as-group-vpczoneidentifier"
        )



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags
from .validators import boolean, integer
from .validators.codebuild import (
    validate_artifacts,
    validate_credentials_provider,
    validate_environment,
    validate_environment_variable,
    validate_environmentvariable_or_list,
    validate_image_pull_credentials,
    validate_project_cache,
    validate_project_triggers,
    validate_projectfilesystemlocation_type,
    validate_source,
    validate_source_auth,
    validate_status,
    validate_webhookfilter_type,
)


class Fleet(AWSObject):
    """
    `Fleet <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codebuild-fleet.html>`__
    """

    resource_type = "AWS::CodeBuild::Fleet"

    props: PropsDictType = {
        "BaseCapacity": (integer, False),
        "ComputeType": (str, False),
        "EnvironmentType": (str, False),
        "Name": (str, False),
        "Tags": (Tags, False),
    }


class Artifacts(AWSProperty):
    """
    `Artifacts <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codebuild-project-artifacts.html>`__
    """

    props: PropsDictType = {
        "ArtifactIdentifier": (str, False),
        "EncryptionDisabled": (boolean, False),
        "Location": (str, False),
        "Name": (str, False),
        "NamespaceType": (str, False),
        "OverrideArtifactName": (boolean, False),
        "Packaging": (str, False),
        "Path": (str, False),
        "Type": (str, True),
    }

    def validate(self):
        validate_artifacts(self)


class EnvironmentVariable(AWSProperty):
    """
    `EnvironmentVariable <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codebuild-project-environmentvariable.html>`__
    """

    props: PropsDictType = {
        "Name": (str, True),
        "Type": (str, False),
        "Value": (str, True),
    }

    def validate(self):
        validate_environment_variable(self)


class ProjectFleet(AWSProperty):
    """
    `ProjectFleet <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codebuild-project-projectfleet.html>`__
    """

    props: PropsDictType = {
        "FleetArn": (str, False),
    }


class RegistryCredential(AWSProperty):
    """
    `RegistryCredential <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codebuild-project-registrycredential.html>`__
    """

    props: PropsDictType = {
        "Credential": (str, True),
        "CredentialProvider": (validate_credentials_provider, True),
    }


class Environment(AWSProperty):
    """
    `Environment <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codebuild-project-environment.html>`__
    """

    props: PropsDictType = {
        "Certificate": (str, False),
        "ComputeType": (str, True),
        "EnvironmentVariables": (validate_environmentvariable_or_list, False),
        "Fleet": (ProjectFleet, False),
        "Image": (str, True),
        "ImagePullCredentialsType": (validate_image_pull_credentials, False),
        "PrivilegedMode": (boolean, False),
        "RegistryCredential": (RegistryCredential, False),
        "Type": (str, True),
    }

    def validate(self):
        validate_environment(self)


class CloudWatchLogs(AWSProperty):
    """
    `CloudWatchLogs <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codebuild-project-cloudwatchlogsconfig.html>`__
    """

    props: PropsDictType = {
        "GroupName": (str, False),
        "Status": (validate_status, True),
        "StreamName": (str, False),
    }


class S3Logs(AWSProperty):
    """
    `S3Logs <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codebuild-project-s3logsconfig.html>`__
    """

    props: PropsDictType = {
        "EncryptionDisabled": (boolean, False),
        "Location": (str, False),
        "Status": (validate_status, True),
    }


class LogsConfig(AWSProperty):
    """
    `LogsConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codebuild-project-logsconfig.html>`__
    """

    props: PropsDictType = {
        "CloudWatchLogs": (CloudWatchLogs, False),
        "S3Logs": (S3Logs, False),
    }


class BatchRestrictions(AWSProperty):
    """
    `BatchRestrictions <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codebuild-project-batchrestrictions.html>`__
    """

    props: PropsDictType = {
        "ComputeTypesAllowed": ([str], False),
        "MaximumBuildsAllowed": (integer, False),
    }


class ProjectBuildBatchConfig(AWSProperty):
    """
    `ProjectBuildBatchConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codebuild-project-projectbuildbatchconfig.html>`__
    """

    props: PropsDictType = {
        "BatchReportMode": (str, False),
        "CombineArtifacts": (boolean, False),
        "Restrictions": (BatchRestrictions, False),
        "ServiceRole": (str, False),
        "TimeoutInMins": (integer, False),
    }


class ProjectCache(AWSProperty):
    """
    `ProjectCache <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codebuild-project-projectcache.html>`__
    """

    props: PropsDictType = {
        "Location": (str, False),
        "Modes": ([str], False),
        "Type": (str, True),
    }

    def validate(self):
        validate_project_cache(self)


class ProjectFileSystemLocation(AWSProperty):
    """
    `ProjectFileSystemLocation <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codebuild-project-projectfilesystemlocation.html>`__
    """

    props: PropsDictType = {
        "Identifier": (str, True),
        "Location": (str, True),
        "MountOptions": (str, False),
        "MountPoint": (str, True),
        "Type": (validate_projectfilesystemlocation_type, True),
    }


class ProjectSourceVersion(AWSProperty):
    """
    `ProjectSourceVersion <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codebuild-project-projectsourceversion.html>`__
    """

    props: PropsDictType = {
        "SourceIdentifier": (str, True),
        "SourceVersion": (str, False),
    }


class ProjectTriggers(AWSProperty):
    """
    `ProjectTriggers <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codebuild-project-projecttriggers.html>`__
    """

    props: PropsDictType = {
        "BuildType": (str, False),
        "FilterGroups": (list, False),
        "Webhook": (boolean, False),
    }

    def validate(self):
        validate_project_triggers(self)


class BuildStatusConfig(AWSProperty):
    """
    `BuildStatusConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codebuild-project-buildstatusconfig.html>`__
    """

    props: PropsDictType = {
        "Context": (str, False),
        "TargetUrl": (str, False),
    }


class GitSubmodulesConfig(AWSProperty):
    """
    `GitSubmodulesConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codebuild-project-gitsubmodulesconfig.html>`__
    """

    props: PropsDictType = {
        "FetchSubmodules": (boolean, True),
    }


class SourceAuth(AWSProperty):
    """
    `SourceAuth <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codebuild-project-sourceauth.html>`__
    """

    props: PropsDictType = {
        "Resource": (str, False),
        "Type": (str, True),
    }

    def validate(self):
        validate_source_auth(self)


class Source(AWSProperty):
    """
    `Source <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codebuild-project-source.html>`__
    """

    props: PropsDictType = {
        "Auth": (SourceAuth, False),
        "BuildSpec": (str, False),
        "BuildStatusConfig": (BuildStatusConfig, False),
        "GitCloneDepth": (integer, False),
        "GitSubmodulesConfig": (GitSubmodulesConfig, False),
        "InsecureSsl": (boolean, False),
        "Location": (str, False),
        "ReportBuildStatus": (boolean, False),
        "SourceIdentifier": (str, False),
        "Type": (str, True),
    }

    def validate(self):
        validate_source(self)


class VpcConfig(AWSProperty):
    """
    `VpcConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codebuild-project-vpcconfig.html>`__
    """

    props: PropsDictType = {
        "SecurityGroupIds": ([str], False),
        "Subnets": ([str], False),
        "VpcId": (str, False),
    }


class Project(AWSObject):
    """
    `Project <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codebuild-project.html>`__
    """

    resource_type = "AWS::CodeBuild::Project"

    props: PropsDictType = {
        "Artifacts": (Artifacts, True),
        "BadgeEnabled": (boolean, False),
        "BuildBatchConfig": (ProjectBuildBatchConfig, False),
        "Cache": (ProjectCache, False),
        "ConcurrentBuildLimit": (integer, False),
        "Description": (str, False),
        "EncryptionKey": (str, False),
        "Environment": (Environment, True),
        "FileSystemLocations": ([ProjectFileSystemLocation], False),
        "LogsConfig": (LogsConfig, False),
        "Name": (str, False),
        "QueuedTimeoutInMinutes": (integer, False),
        "ResourceAccessRole": (str, False),
        "SecondaryArtifacts": ([Artifacts], False),
        "SecondarySourceVersions": ([ProjectSourceVersion], False),
        "SecondarySources": ([Source], False),
        "ServiceRole": (str, True),
        "Source": (Source, True),
        "SourceVersion": (str, False),
        "Tags": (Tags, False),
        "TimeoutInMinutes": (integer, False),
        "Triggers": (ProjectTriggers, False),
        "Visibility": (str, False),
        "VpcConfig": (VpcConfig, False),
    }


class S3ReportExportConfig(AWSProperty):
    """
    `S3ReportExportConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codebuild-reportgroup-s3reportexportconfig.html>`__
    """

    props: PropsDictType = {
        "Bucket": (str, True),
        "BucketOwner": (str, False),
        "EncryptionDisabled": (boolean, False),
        "EncryptionKey": (str, False),
        "Packaging": (str, False),
        "Path": (str, False),
    }


class ReportExportConfig(AWSProperty):
    """
    `ReportExportConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codebuild-reportgroup-reportexportconfig.html>`__
    """

    props: PropsDictType = {
        "ExportConfigType": (str, True),
        "S3Destination": (S3ReportExportConfig, False),
    }


class ReportGroup(AWSObject):
    """
    `ReportGroup <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codebuild-reportgroup.html>`__
    """

    resource_type = "AWS::CodeBuild::ReportGroup"

    props: PropsDictType = {
        "DeleteReports": (boolean, False),
        "ExportConfig": (ReportExportConfig, True),
        "Name": (str, False),
        "Tags": (Tags, False),
        "Type": (str, True),
    }


class SourceCredential(AWSObject):
    """
    `SourceCredential <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codebuild-sourcecredential.html>`__
    """

    resource_type = "AWS::CodeBuild::SourceCredential"

    props: PropsDictType = {
        "AuthType": (str, True),
        "ServerType": (str, True),
        "Token": (str, True),
        "Username": (str, False),
    }


class WebhookFilter(AWSProperty):
    """
    `WebhookFilter <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codebuild-project-webhookfilter.html>`__
    """

    props: PropsDictType = {
        "ExcludeMatchedPattern": (boolean, False),
        "Pattern": (str, True),
        "Type": (validate_webhookfilter_type, True),
    }



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags
from .validators import boolean, integer
from .validators.elasticloadbalancingv2 import TARGET_TYPE_ALB  # noqa: F401
from .validators.elasticloadbalancingv2 import TARGET_TYPE_INSTANCE  # noqa: F401
from .validators.elasticloadbalancingv2 import TARGET_TYPE_IP  # noqa: F401
from .validators.elasticloadbalancingv2 import TARGET_TYPE_LAMBDA  # noqa: F401
from .validators.elasticloadbalancingv2 import (
    tg_healthcheck_port,
    validate_action,
    validate_elb_name,
    validate_fixed_response_config,
    validate_loadbalancer,
    validate_network_port,
    validate_redirect_config,
    validate_tags_or_list,
    validate_target_group,
    validate_target_type,
)


class AuthenticateCognitoConfig(AWSProperty):
    """
    `AuthenticateCognitoConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-listenerrule-authenticatecognitoconfig.html>`__
    """

    props: PropsDictType = {
        "AuthenticationRequestExtraParams": (dict, False),
        "OnUnauthenticatedRequest": (str, False),
        "Scope": (str, False),
        "SessionCookieName": (str, False),
        "SessionTimeout": (integer, False),
        "UserPoolArn": (str, True),
        "UserPoolClientId": (str, True),
        "UserPoolDomain": (str, True),
    }


class AuthenticateOidcConfig(AWSProperty):
    """
    `AuthenticateOidcConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-listener-authenticateoidcconfig.html>`__
    """

    props: PropsDictType = {
        "AuthenticationRequestExtraParams": (dict, False),
        "AuthorizationEndpoint": (str, True),
        "ClientId": (str, True),
        "ClientSecret": (str, False),
        "Issuer": (str, True),
        "OnUnauthenticatedRequest": (str, False),
        "Scope": (str, False),
        "SessionCookieName": (str, False),
        "SessionTimeout": (str, False),
        "TokenEndpoint": (str, True),
        "UseExistingClientSecret": (boolean, False),
        "UserInfoEndpoint": (str, True),
    }


class FixedResponseConfig(AWSProperty):
    """
    `FixedResponseConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-listenerrule-fixedresponseconfig.html>`__
    """

    props: PropsDictType = {
        "ContentType": (str, False),
        "MessageBody": (str, False),
        "StatusCode": (str, True),
    }

    def validate(self):
        validate_fixed_response_config(self)


class TargetGroupStickinessConfig(AWSProperty):
    """
    `TargetGroupStickinessConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-listenerrule-targetgroupstickinessconfig.html>`__
    """

    props: PropsDictType = {
        "DurationSeconds": (integer, False),
        "Enabled": (boolean, False),
    }


class TargetGroupTuple(AWSProperty):
    """
    `TargetGroupTuple <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-listenerrule-targetgrouptuple.html>`__
    """

    props: PropsDictType = {
        "TargetGroupArn": (str, False),
        "Weight": (integer, False),
    }


class ForwardConfig(AWSProperty):
    """
    `ForwardConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-listenerrule-forwardconfig.html>`__
    """

    props: PropsDictType = {
        "TargetGroupStickinessConfig": (TargetGroupStickinessConfig, False),
        "TargetGroups": ([TargetGroupTuple], False),
    }


class RedirectConfig(AWSProperty):
    """
    `RedirectConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-listenerrule-redirectconfig.html>`__
    """

    props: PropsDictType = {
        "Host": (str, False),
        "Path": (str, False),
        "Port": (str, False),
        "Protocol": (str, False),
        "Query": (str, False),
        "StatusCode": (str, True),
    }

    def validate(self):
        validate_redirect_config(self)


class Action(AWSProperty):
    """
    `Action <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-listener-action.html>`__
    """

    props: PropsDictType = {
        "AuthenticateCognitoConfig": (AuthenticateCognitoConfig, False),
        "AuthenticateOidcConfig": (AuthenticateOidcConfig, False),
        "FixedResponseConfig": (FixedResponseConfig, False),
        "ForwardConfig": (ForwardConfig, False),
        "Order": (integer, False),
        "RedirectConfig": (RedirectConfig, False),
        "TargetGroupArn": (str, False),
        "Type": (str, True),
    }

    def validate(self):
        validate_action(self)


class Certificate(AWSProperty):
    """
    `Certificate <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-listener-certificates.html>`__
    """

    props: PropsDictType = {
        "CertificateArn": (str, False),
    }


class MutualAuthentication(AWSProperty):
    """
    `MutualAuthentication <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-listener-mutualauthentication.html>`__
    """

    props: PropsDictType = {
        "IgnoreClientCertificateExpiry": (boolean, False),
        "Mode": (str, False),
        "TrustStoreArn": (str, False),
    }


class Listener(AWSObject):
    """
    `Listener <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-elasticloadbalancingv2-listener.html>`__
    """

    resource_type = "AWS::ElasticLoadBalancingV2::Listener"

    props: PropsDictType = {
        "AlpnPolicy": ([str], False),
        "Certificates": ([Certificate], False),
        "DefaultActions": ([Action], True),
        "LoadBalancerArn": (str, True),
        "MutualAuthentication": (MutualAuthentication, False),
        "Port": (validate_network_port, False),
        "Protocol": (str, False),
        "SslPolicy": (str, False),
    }


class ListenerCertificate(AWSObject):
    """
    `ListenerCertificate <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-elasticloadbalancingv2-listenercertificate.html>`__
    """

    resource_type = "AWS::ElasticLoadBalancingV2::ListenerCertificate"

    props: PropsDictType = {
        "Certificates": ([Certificate], True),
        "ListenerArn": (str, True),
    }


class HostHeaderConfig(AWSProperty):
    """
    `HostHeaderConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-listenerrule-hostheaderconfig.html>`__
    """

    props: PropsDictType = {
        "Values": ([str], False),
    }


class HttpHeaderConfig(AWSProperty):
    """
    `HttpHeaderConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-listenerrule-httpheaderconfig.html>`__
    """

    props: PropsDictType = {
        "HttpHeaderName": (str, False),
        "Values": ([str], False),
    }


class HttpRequestMethodConfig(AWSProperty):
    """
    `HttpRequestMethodConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-listenerrule-httprequestmethodconfig.html>`__
    """

    props: PropsDictType = {
        "Values": ([str], False),
    }


class PathPatternConfig(AWSProperty):
    """
    `PathPatternConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-listenerrule-pathpatternconfig.html>`__
    """

    props: PropsDictType = {
        "Values": ([str], False),
    }


class QueryStringKeyValue(AWSProperty):
    """
    `QueryStringKeyValue <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-listenerrule-querystringkeyvalue.html>`__
    """

    props: PropsDictType = {
        "Key": (str, False),
        "Value": (str, False),
    }


class QueryStringConfig(AWSProperty):
    """
    `QueryStringConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-listenerrule-querystringconfig.html>`__
    """

    props: PropsDictType = {
        "Values": ([QueryStringKeyValue], False),
    }


class SourceIpConfig(AWSProperty):
    """
    `SourceIpConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-listenerrule-sourceipconfig.html>`__
    """

    props: PropsDictType = {
        "Values": ([str], False),
    }


class Condition(AWSProperty):
    """
    `Condition <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-listenerrule-rulecondition.html>`__
    """

    props: PropsDictType = {
        "Field": (str, False),
        "HostHeaderConfig": (HostHeaderConfig, False),
        "HttpHeaderConfig": (HttpHeaderConfig, False),
        "HttpRequestMethodConfig": (HttpRequestMethodConfig, False),
        "PathPatternConfig": (PathPatternConfig, False),
        "QueryStringConfig": (QueryStringConfig, False),
        "SourceIpConfig": (SourceIpConfig, False),
        "Values": ([str], False),
    }


class ListenerRuleAuthenticateOidcConfig(AWSProperty):
    """
    `ListenerRuleAuthenticateOidcConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-listenerrule-authenticateoidcconfig.html>`__
    """

    props: PropsDictType = {
        "AuthenticationRequestExtraParams": (dict, False),
        "AuthorizationEndpoint": (str, True),
        "ClientId": (str, True),
        "ClientSecret": (str, False),
        "Issuer": (str, True),
        "OnUnauthenticatedRequest": (str, False),
        "Scope": (str, False),
        "SessionCookieName": (str, False),
        "SessionTimeout": (integer, False),
        "TokenEndpoint": (str, True),
        "UseExistingClientSecret": (boolean, False),
        "UserInfoEndpoint": (str, True),
    }


class ListenerRuleAction(AWSProperty):
    """
    `ListenerRuleAction <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-listenerrule-action.html>`__
    """

    props: PropsDictType = {
        "AuthenticateCognitoConfig": (AuthenticateCognitoConfig, False),
        "AuthenticateOidcConfig": (ListenerRuleAuthenticateOidcConfig, False),
        "FixedResponseConfig": (FixedResponseConfig, False),
        "ForwardConfig": (ForwardConfig, False),
        "Order": (integer, False),
        "RedirectConfig": (RedirectConfig, False),
        "TargetGroupArn": (str, False),
        "Type": (str, True),
    }


class ListenerRule(AWSObject):
    """
    `ListenerRule <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-elasticloadbalancingv2-listenerrule.html>`__
    """

    resource_type = "AWS::ElasticLoadBalancingV2::ListenerRule"

    props: PropsDictType = {
        "Actions": ([ListenerRuleAction], True),
        "Conditions": ([Condition], True),
        "ListenerArn": (str, False),
        "Priority": (integer, True),
    }


class LoadBalancerAttributes(AWSProperty):
    """
    `LoadBalancerAttributes <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-loadbalancer-loadbalancerattribute.html>`__
    """

    props: PropsDictType = {
        "Key": (str, False),
        "Value": (str, False),
    }


class SubnetMapping(AWSProperty):
    """
    `SubnetMapping <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-loadbalancer-subnetmapping.html>`__
    """

    props: PropsDictType = {
        "AllocationId": (str, False),
        "IPv6Address": (str, False),
        "PrivateIPv4Address": (str, False),
        "SubnetId": (str, True),
    }


class LoadBalancer(AWSObject):
    """
    `LoadBalancer <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-elasticloadbalancingv2-loadbalancer.html>`__
    """

    resource_type = "AWS::ElasticLoadBalancingV2::LoadBalancer"

    props: PropsDictType = {
        "EnforceSecurityGroupInboundRulesOnPrivateLinkTraffic": (str, False),
        "IpAddressType": (str, False),
        "LoadBalancerAttributes": ([LoadBalancerAttributes], False),
        "Name": (validate_elb_name, False),
        "Scheme": (str, False),
        "SecurityGroups": ([str], False),
        "SubnetMappings": ([SubnetMapping], False),
        "Subnets": ([str], False),
        "Tags": (validate_tags_or_list, False),
        "Type": (str, False),
    }

    def validate(self):
        validate_loadbalancer(self)


class Matcher(AWSProperty):
    """
    `Matcher <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-targetgroup-matcher.html>`__
    """

    props: PropsDictType = {
        "GrpcCode": (str, False),
        "HttpCode": (str, False),
    }


class TargetDescription(AWSProperty):
    """
    `TargetDescription <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-targetgroup-targetdescription.html>`__
    """

    props: PropsDictType = {
        "AvailabilityZone": (str, False),
        "Id": (str, True),
        "Port": (validate_network_port, False),
    }


class TargetGroupAttribute(AWSProperty):
    """
    `TargetGroupAttribute <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-targetgroup-targetgroupattribute.html>`__
    """

    props: PropsDictType = {
        "Key": (str, False),
        "Value": (str, False),
    }


class TargetGroup(AWSObject):
    """
    `TargetGroup <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-elasticloadbalancingv2-targetgroup.html>`__
    """

    resource_type = "AWS::ElasticLoadBalancingV2::TargetGroup"

    props: PropsDictType = {
        "HealthCheckEnabled": (boolean, False),
        "HealthCheckIntervalSeconds": (integer, False),
        "HealthCheckPath": (str, False),
        "HealthCheckPort": (tg_healthcheck_port, False),
        "HealthCheckProtocol": (str, False),
        "HealthCheckTimeoutSeconds": (integer, False),
        "HealthyThresholdCount": (integer, False),
        "IpAddressType": (str, False),
        "Matcher": (Matcher, False),
        "Name": (str, False),
        "Port": (validate_network_port, False),
        "Protocol": (str, False),
        "ProtocolVersion": (str, False),
        "Tags": (validate_tags_or_list, False),
        "TargetGroupAttributes": ([TargetGroupAttribute], False),
        "TargetType": (validate_target_type, False),
        "Targets": ([TargetDescription], False),
        "UnhealthyThresholdCount": (integer, False),
        "VpcId": (str, False),
    }

    def validate(self):
        validate_target_group(self)


class TrustStore(AWSObject):
    """
    `TrustStore <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-elasticloadbalancingv2-truststore.html>`__
    """

    resource_type = "AWS::ElasticLoadBalancingV2::TrustStore"

    props: PropsDictType = {
        "CaCertificatesBundleS3Bucket": (str, False),
        "CaCertificatesBundleS3Key": (str, False),
        "CaCertificatesBundleS3ObjectVersion": (str, False),
        "Name": (str, False),
        "Tags": (Tags, False),
    }


class RevocationContent(AWSProperty):
    """
    `RevocationContent <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-truststorerevocation-revocationcontent.html>`__
    """

    props: PropsDictType = {
        "RevocationType": (str, False),
        "S3Bucket": (str, False),
        "S3Key": (str, False),
        "S3ObjectVersion": (str, False),
    }


class TrustStoreRevocation(AWSObject):
    """
    `TrustStoreRevocation <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-elasticloadbalancingv2-truststorerevocation.html>`__
    """

    resource_type = "AWS::ElasticLoadBalancingV2::TrustStoreRevocation"

    props: PropsDictType = {
        "RevocationContents": ([RevocationContent], False),
        "TrustStoreArn": (str, False),
    }


class TrustStoreRevocationProperty(AWSProperty):
    """
    `TrustStoreRevocationProperty <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticloadbalancingv2-truststorerevocation-truststorerevocation.html>`__
    """

    props: PropsDictType = {
        "NumberOfRevokedEntries": (integer, False),
        "RevocationId": (str, False),
        "RevocationType": (str, False),
        "TrustStoreArn": (str, False),
    }



from troposphere import Tags, Template
from troposphere.iotanalytics import (
    Action,
    Activity,
    ActivityChannel,
    ActivityDatastore,
    Channel,
    ChannelStorage,
    CustomerManagedS3,
    Dataset,
    DatasetContentDeliveryRule,
    DatasetContentDeliveryRuleDestination,
    Datastore,
    DatastoreStorage,
    Pipeline,
    RetentionPeriod,
    S3DestinationConfiguration,
    Trigger,
    TriggeringDataset,
    VersioningConfiguration,
)

t = Template()

channel = Channel(
    "TestChannel",
    ChannelName="testchannel",
    ChannelStorage=ChannelStorage(
        CustomerManagedS3=CustomerManagedS3(
            Bucket="customerbucket",
            KeyPrefix="bobdog",
            RoleArn="arn",
        )
    ),
    RetentionPeriod=RetentionPeriod(
        NumberOfDays=10,
    ),
    Tags=Tags(Manufacturer="AmazonWebServices"),
)

pipeline = Pipeline(
    "TestPipeline",
    PipelineActivities=[
        Activity(
            Channel=ActivityChannel(
                ChannelName="ChannelName",
                Name="testchannel",
                Next="DatastoreActivity",
            ),
        ),
        Activity(
            Datastore=ActivityDatastore(
                Name="DatastoreActivity",
                DatastoreName="testdatastore",
            ),
        ),
    ],
    PipelineName="testpipeline",
    Tags=Tags(Manufacturer="AmazonWebServices"),
)

datastore = Datastore(
    "TestDatastore",
    DatastoreName="testdatastore",
    DatastoreStorage=DatastoreStorage(
        ServiceManagedS3={},
    ),
    RetentionPeriod=RetentionPeriod(
        NumberOfDays=365,
    ),
    Tags=Tags(Manufacturer="AmazonWebServices"),
)

dataset = Dataset(
    "TestDataset",
    Actions=[
        Action(
            ActionName="actionname",
        ),
    ],
    ContentDeliveryRules=[
        DatasetContentDeliveryRule(
            Destination=DatasetContentDeliveryRuleDestination(
                S3DestinationConfiguration=S3DestinationConfiguration(
                    Bucket="testbucket",
                    Key="testkey",
                    RoleArn="arn",
                ),
            ),
            EntryName="entryname",
        )
    ],
    DatasetName="testdataset",
    RetentionPeriod=RetentionPeriod(
        Unlimited=True,
    ),
    Tags=Tags(Manufacturer="AmazonWebServices"),
    Triggers=[
        Trigger(
            TriggeringDataset=TriggeringDataset(DatasetName="testdataset"),
        ),
    ],
    VersioningConfiguration=VersioningConfiguration(
        Unlimited=True,
    ),
)

t.add_resource(channel)
t.add_resource(pipeline)
t.add_resource(datastore)
t.add_resource(dataset)

print(t.to_json())



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags
from .validators import boolean


class DeliveryOptions(AWSProperty):
    """
    `DeliveryOptions <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-configurationset-deliveryoptions.html>`__
    """

    props: PropsDictType = {
        "SendingPoolName": (str, False),
        "TlsPolicy": (str, False),
    }


class ReputationOptions(AWSProperty):
    """
    `ReputationOptions <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-configurationset-reputationoptions.html>`__
    """

    props: PropsDictType = {
        "ReputationMetricsEnabled": (boolean, False),
    }


class SendingOptions(AWSProperty):
    """
    `SendingOptions <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-configurationset-sendingoptions.html>`__
    """

    props: PropsDictType = {
        "SendingEnabled": (boolean, False),
    }


class SuppressionOptions(AWSProperty):
    """
    `SuppressionOptions <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-configurationset-suppressionoptions.html>`__
    """

    props: PropsDictType = {
        "SuppressedReasons": ([str], False),
    }


class TrackingOptions(AWSProperty):
    """
    `TrackingOptions <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-configurationset-trackingoptions.html>`__
    """

    props: PropsDictType = {
        "CustomRedirectDomain": (str, False),
    }


class DashboardOptions(AWSProperty):
    """
    `DashboardOptions <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-configurationset-dashboardoptions.html>`__
    """

    props: PropsDictType = {
        "EngagementMetrics": (str, True),
    }


class GuardianOptions(AWSProperty):
    """
    `GuardianOptions <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-configurationset-guardianoptions.html>`__
    """

    props: PropsDictType = {
        "OptimizedSharedDelivery": (str, True),
    }


class VdmOptions(AWSProperty):
    """
    `VdmOptions <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-configurationset-vdmoptions.html>`__
    """

    props: PropsDictType = {
        "DashboardOptions": (DashboardOptions, False),
        "GuardianOptions": (GuardianOptions, False),
    }


class ConfigurationSet(AWSObject):
    """
    `ConfigurationSet <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ses-configurationset.html>`__
    """

    resource_type = "AWS::SES::ConfigurationSet"

    props: PropsDictType = {
        "DeliveryOptions": (DeliveryOptions, False),
        "Name": (str, False),
        "ReputationOptions": (ReputationOptions, False),
        "SendingOptions": (SendingOptions, False),
        "SuppressionOptions": (SuppressionOptions, False),
        "TrackingOptions": (TrackingOptions, False),
        "VdmOptions": (VdmOptions, False),
    }


class DimensionConfiguration(AWSProperty):
    """
    `DimensionConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-configurationseteventdestination-dimensionconfiguration.html>`__
    """

    props: PropsDictType = {
        "DefaultDimensionValue": (str, True),
        "DimensionName": (str, True),
        "DimensionValueSource": (str, True),
    }


class CloudWatchDestination(AWSProperty):
    """
    `CloudWatchDestination <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-configurationseteventdestination-cloudwatchdestination.html>`__
    """

    props: PropsDictType = {
        "DimensionConfigurations": ([DimensionConfiguration], False),
    }


class KinesisFirehoseDestination(AWSProperty):
    """
    `KinesisFirehoseDestination <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-configurationseteventdestination-kinesisfirehosedestination.html>`__
    """

    props: PropsDictType = {
        "DeliveryStreamARN": (str, True),
        "IAMRoleARN": (str, True),
    }


class SnsDestination(AWSProperty):
    """
    `SnsDestination <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-configurationseteventdestination-snsdestination.html>`__
    """

    props: PropsDictType = {
        "TopicARN": (str, True),
    }


class EventDestination(AWSProperty):
    """
    `EventDestination <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-configurationseteventdestination-eventdestination.html>`__
    """

    props: PropsDictType = {
        "CloudWatchDestination": (CloudWatchDestination, False),
        "Enabled": (boolean, False),
        "KinesisFirehoseDestination": (KinesisFirehoseDestination, False),
        "MatchingEventTypes": ([str], True),
        "Name": (str, False),
        "SnsDestination": (SnsDestination, False),
    }


class ConfigurationSetEventDestination(AWSObject):
    """
    `ConfigurationSetEventDestination <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ses-configurationseteventdestination.html>`__
    """

    resource_type = "AWS::SES::ConfigurationSetEventDestination"

    props: PropsDictType = {
        "ConfigurationSetName": (str, True),
        "EventDestination": (EventDestination, True),
    }


class Topic(AWSProperty):
    """
    `Topic <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-contactlist-topic.html>`__
    """

    props: PropsDictType = {
        "DefaultSubscriptionStatus": (str, True),
        "Description": (str, False),
        "DisplayName": (str, True),
        "TopicName": (str, True),
    }


class ContactList(AWSObject):
    """
    `ContactList <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ses-contactlist.html>`__
    """

    resource_type = "AWS::SES::ContactList"

    props: PropsDictType = {
        "ContactListName": (str, False),
        "Description": (str, False),
        "Tags": (Tags, False),
        "Topics": ([Topic], False),
    }


class DedicatedIpPool(AWSObject):
    """
    `DedicatedIpPool <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ses-dedicatedippool.html>`__
    """

    resource_type = "AWS::SES::DedicatedIpPool"

    props: PropsDictType = {
        "PoolName": (str, False),
        "ScalingMode": (str, False),
    }


class ConfigurationSetAttributes(AWSProperty):
    """
    `ConfigurationSetAttributes <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-emailidentity-configurationsetattributes.html>`__
    """

    props: PropsDictType = {
        "ConfigurationSetName": (str, False),
    }


class DkimAttributes(AWSProperty):
    """
    `DkimAttributes <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-emailidentity-dkimattributes.html>`__
    """

    props: PropsDictType = {
        "SigningEnabled": (boolean, False),
    }


class DkimSigningAttributes(AWSProperty):
    """
    `DkimSigningAttributes <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-emailidentity-dkimsigningattributes.html>`__
    """

    props: PropsDictType = {
        "DomainSigningPrivateKey": (str, False),
        "DomainSigningSelector": (str, False),
        "NextSigningKeyLength": (str, False),
    }


class FeedbackAttributes(AWSProperty):
    """
    `FeedbackAttributes <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-emailidentity-feedbackattributes.html>`__
    """

    props: PropsDictType = {
        "EmailForwardingEnabled": (boolean, False),
    }


class MailFromAttributes(AWSProperty):
    """
    `MailFromAttributes <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-emailidentity-mailfromattributes.html>`__
    """

    props: PropsDictType = {
        "BehaviorOnMxFailure": (str, False),
        "MailFromDomain": (str, False),
    }


class EmailIdentity(AWSObject):
    """
    `EmailIdentity <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ses-emailidentity.html>`__
    """

    resource_type = "AWS::SES::EmailIdentity"

    props: PropsDictType = {
        "ConfigurationSetAttributes": (ConfigurationSetAttributes, False),
        "DkimAttributes": (DkimAttributes, False),
        "DkimSigningAttributes": (DkimSigningAttributes, False),
        "EmailIdentity": (str, True),
        "FeedbackAttributes": (FeedbackAttributes, False),
        "MailFromAttributes": (MailFromAttributes, False),
    }


class IpFilter(AWSProperty):
    """
    `IpFilter <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-receiptfilter-ipfilter.html>`__
    """

    props: PropsDictType = {
        "Cidr": (str, True),
        "Policy": (str, True),
    }


class Filter(AWSProperty):
    """
    `Filter <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-receiptfilter-filter.html>`__
    """

    props: PropsDictType = {
        "IpFilter": (IpFilter, True),
        "Name": (str, False),
    }


class ReceiptFilter(AWSObject):
    """
    `ReceiptFilter <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ses-receiptfilter.html>`__
    """

    resource_type = "AWS::SES::ReceiptFilter"

    props: PropsDictType = {
        "Filter": (Filter, True),
    }


class AddHeaderAction(AWSProperty):
    """
    `AddHeaderAction <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-receiptrule-addheaderaction.html>`__
    """

    props: PropsDictType = {
        "HeaderName": (str, True),
        "HeaderValue": (str, True),
    }


class BounceAction(AWSProperty):
    """
    `BounceAction <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-receiptrule-bounceaction.html>`__
    """

    props: PropsDictType = {
        "Message": (str, True),
        "Sender": (str, True),
        "SmtpReplyCode": (str, True),
        "StatusCode": (str, False),
        "TopicArn": (str, False),
    }


class LambdaAction(AWSProperty):
    """
    `LambdaAction <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-receiptrule-lambdaaction.html>`__
    """

    props: PropsDictType = {
        "FunctionArn": (str, True),
        "InvocationType": (str, False),
        "TopicArn": (str, False),
    }


class S3Action(AWSProperty):
    """
    `S3Action <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-receiptrule-s3action.html>`__
    """

    props: PropsDictType = {
        "BucketName": (str, True),
        "KmsKeyArn": (str, False),
        "ObjectKeyPrefix": (str, False),
        "TopicArn": (str, False),
    }


class SNSAction(AWSProperty):
    """
    `SNSAction <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-receiptrule-snsaction.html>`__
    """

    props: PropsDictType = {
        "Encoding": (str, False),
        "TopicArn": (str, False),
    }


class StopAction(AWSProperty):
    """
    `StopAction <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-receiptrule-stopaction.html>`__
    """

    props: PropsDictType = {
        "Scope": (str, True),
        "TopicArn": (str, False),
    }


class WorkmailAction(AWSProperty):
    """
    `WorkmailAction <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-receiptrule-workmailaction.html>`__
    """

    props: PropsDictType = {
        "OrganizationArn": (str, True),
        "TopicArn": (str, False),
    }


class Action(AWSProperty):
    """
    `Action <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-receiptrule-action.html>`__
    """

    props: PropsDictType = {
        "AddHeaderAction": (AddHeaderAction, False),
        "BounceAction": (BounceAction, False),
        "LambdaAction": (LambdaAction, False),
        "S3Action": (S3Action, False),
        "SNSAction": (SNSAction, False),
        "StopAction": (StopAction, False),
        "WorkmailAction": (WorkmailAction, False),
    }


class Rule(AWSProperty):
    """
    `Rule <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-receiptrule-rule.html>`__
    """

    props: PropsDictType = {
        "Actions": ([Action], False),
        "Enabled": (boolean, False),
        "Name": (str, False),
        "Recipients": ([str], False),
        "ScanEnabled": (boolean, False),
        "TlsPolicy": (str, False),
    }


class ReceiptRule(AWSObject):
    """
    `ReceiptRule <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ses-receiptrule.html>`__
    """

    resource_type = "AWS::SES::ReceiptRule"

    props: PropsDictType = {
        "After": (str, False),
        "Rule": (Rule, True),
        "RuleSetName": (str, True),
    }


class ReceiptRuleSet(AWSObject):
    """
    `ReceiptRuleSet <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ses-receiptruleset.html>`__
    """

    resource_type = "AWS::SES::ReceiptRuleSet"

    props: PropsDictType = {
        "RuleSetName": (str, False),
    }


class EmailTemplate(AWSProperty):
    """
    `EmailTemplate <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-template-template.html>`__
    """

    props: PropsDictType = {
        "HtmlPart": (str, False),
        "SubjectPart": (str, True),
        "TemplateName": (str, False),
        "TextPart": (str, False),
    }


class Template(AWSObject):
    """
    `Template <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ses-template.html>`__
    """

    resource_type = "AWS::SES::Template"

    props: PropsDictType = {
        "Template": (EmailTemplate, False),
    }


class DashboardAttributes(AWSProperty):
    """
    `DashboardAttributes <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-vdmattributes-dashboardattributes.html>`__
    """

    props: PropsDictType = {
        "EngagementMetrics": (str, False),
    }


class GuardianAttributes(AWSProperty):
    """
    `GuardianAttributes <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-vdmattributes-guardianattributes.html>`__
    """

    props: PropsDictType = {
        "OptimizedSharedDelivery": (str, False),
    }


class VdmAttributes(AWSObject):
    """
    `VdmAttributes <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ses-vdmattributes.html>`__
    """

    resource_type = "AWS::SES::VdmAttributes"

    props: PropsDictType = {
        "DashboardAttributes": (DashboardAttributes, False),
        "GuardianAttributes": (GuardianAttributes, False),
    }



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.


from .. import If
from ..type_defs.compat import Final
from . import elb_name, exactly_one, network_port, one_of, tags_or_list


def tg_healthcheck_port(x):
    """
    Property: TargetGroup.HealthCheckPort
    """
    if isinstance(x, str) and x == "traffic-port":
        return x
    return network_port(x)


def validate_elb_name(x):
    """
    Property: LoadBalancer.Name
    """
    return elb_name(x)


def validate_network_port(x):
    """
    Property: TargetDescription.Port
    Property: Listener.Port
    Property: TargetGroup.Port
    """
    return network_port(x)


def validate_tags_or_list(x):
    """
    Property: LoadBalancer.Tags
    Property: TargetGroup.Tags
    """
    return tags_or_list(x)


def validate_redirect_config(self):
    """
    Class: RedirectConfig
    """
    one_of(
        self.__class__.__name__,
        self.properties,
        "StatusCode",
        ["HTTP_301", "HTTP_302"],
    )


def validate_fixed_response_config(self):
    """
    Class: FixedResponseConfig
    """
    one_of(
        self.__class__.__name__,
        self.properties,
        "ContentType",
        [
            None,
            "text/plain",
            "text/css",
            "text/html",
            "application/javascript",
            "application/json",
        ],
    )


def validate_action(self):
    """
    Class: Action
    """
    one_of(
        self.__class__.__name__,
        self.properties,
        "Type",
        [
            "forward",
            "redirect",
            "fixed-response",
            "authenticate-cognito",
            "authenticate-oidc",
        ],
    )

    def any_property(require_prop, properties):
        return any(p in require_prop for p in properties)

    def requires(action_type, prop):
        properties = [definition for definition in self.properties.keys()]
        if self.properties.get("Type") == action_type and not any_property(
            prop, properties
        ):
            raise ValueError(
                'Type "%s" requires definition of "%s"' % (action_type, prop)
            )
        if (
            any_property(prop, properties)
            and self.properties.get("Type") != action_type
        ):
            raise ValueError(
                'Definition of "%s" allowed only with '
                'type "%s", was: "%s"'
                % (prop, action_type, self.properties.get("Type"))
            )

    requires("forward", ["TargetGroupArn", "ForwardConfig"])
    requires("redirect", ["RedirectConfig"])
    requires("fixed-response", ["FixedResponseConfig"])


TARGET_TYPE_ALB: Final = "alb"
TARGET_TYPE_INSTANCE: Final = "instance"
TARGET_TYPE_IP: Final = "ip"
TARGET_TYPE_LAMBDA: Final = "lambda"


def validate_target_type(target_type):
    """
    Property: TargetGroup.TargetType
    """
    valid_types = [
        TARGET_TYPE_ALB,
        TARGET_TYPE_INSTANCE,
        TARGET_TYPE_IP,
        TARGET_TYPE_LAMBDA,
    ]
    if target_type not in valid_types:
        raise ValueError(
            'TargetGroup.TargetType must be one of: "%s"' % ", ".join(valid_types)
        )
    return target_type


def validate_target_group(self):
    """
    Class: TargetGroup
    """

    def check_properties(action_types, props_to_check, required):
        for this_type in action_types:
            self_props = self.properties
            if self_props.get("TargetType") == this_type:
                invalid_props = []
                for prop in props_to_check:
                    if (prop not in self_props and required is True) or (
                        prop in self_props and required is False
                    ):
                        invalid_props.append(prop)

                if len(invalid_props) > 0:
                    # Make error message more readable in the default case
                    type_msg = (
                        "Omitting TargetType"
                        if this_type is None
                        else 'TargetType of "%s"' % this_type
                    )

                    raise ValueError(
                        '%s in "%s" %s definitions of %s'
                        % (
                            type_msg,
                            self.__class__.__name__,
                            "requires" if required is True else "must not contain",
                            str(invalid_props).strip("[]"),
                        )
                    )

    # None defaults to instance as per the AWS docs
    check_properties(
        [None, TARGET_TYPE_INSTANCE, TARGET_TYPE_IP],
        ["Port", "Protocol", "VpcId"],
        True,
    )
    check_properties([TARGET_TYPE_LAMBDA], ["Port", "Protocol", "VpcId"], False)


def validate_loadbalancer(self):
    """
    Class: LoadBalancer
    """
    conds = [
        "SubnetMappings",
        "Subnets",
    ]

    def check_if(names, props):
        validated = []
        for name in names:
            validated.append(name in props and isinstance(props[name], If))
        return all(validated)

    if check_if(conds, self.properties):
        return

    exactly_one(self.__class__.__name__, self.properties, conds)



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags
from .validators import double


class BrowserSettings(AWSObject):
    """
    `BrowserSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspacesweb-browsersettings.html>`__
    """

    resource_type = "AWS::WorkSpacesWeb::BrowserSettings"

    props: PropsDictType = {
        "AdditionalEncryptionContext": (dict, False),
        "BrowserPolicy": (str, False),
        "CustomerManagedKey": (str, False),
        "Tags": (Tags, False),
    }


class IdentityProvider(AWSObject):
    """
    `IdentityProvider <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspacesweb-identityprovider.html>`__
    """

    resource_type = "AWS::WorkSpacesWeb::IdentityProvider"

    props: PropsDictType = {
        "IdentityProviderDetails": (dict, True),
        "IdentityProviderName": (str, True),
        "IdentityProviderType": (str, True),
        "PortalArn": (str, False),
    }


class IpRule(AWSProperty):
    """
    `IpRule <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-workspacesweb-ipaccesssettings-iprule.html>`__
    """

    props: PropsDictType = {
        "Description": (str, False),
        "IpRange": (str, True),
    }


class IpAccessSettings(AWSObject):
    """
    `IpAccessSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspacesweb-ipaccesssettings.html>`__
    """

    resource_type = "AWS::WorkSpacesWeb::IpAccessSettings"

    props: PropsDictType = {
        "AdditionalEncryptionContext": (dict, False),
        "CustomerManagedKey": (str, False),
        "Description": (str, False),
        "DisplayName": (str, False),
        "IpRules": ([IpRule], True),
        "Tags": (Tags, False),
    }


class NetworkSettings(AWSObject):
    """
    `NetworkSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspacesweb-networksettings.html>`__
    """

    resource_type = "AWS::WorkSpacesWeb::NetworkSettings"

    props: PropsDictType = {
        "SecurityGroupIds": ([str], True),
        "SubnetIds": ([str], True),
        "Tags": (Tags, False),
        "VpcId": (str, True),
    }


class Portal(AWSObject):
    """
    `Portal <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspacesweb-portal.html>`__
    """

    resource_type = "AWS::WorkSpacesWeb::Portal"

    props: PropsDictType = {
        "AdditionalEncryptionContext": (dict, False),
        "AuthenticationType": (str, False),
        "BrowserSettingsArn": (str, False),
        "CustomerManagedKey": (str, False),
        "DisplayName": (str, False),
        "IpAccessSettingsArn": (str, False),
        "NetworkSettingsArn": (str, False),
        "Tags": (Tags, False),
        "TrustStoreArn": (str, False),
        "UserAccessLoggingSettingsArn": (str, False),
        "UserSettingsArn": (str, False),
    }


class TrustStore(AWSObject):
    """
    `TrustStore <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspacesweb-truststore.html>`__
    """

    resource_type = "AWS::WorkSpacesWeb::TrustStore"

    props: PropsDictType = {
        "CertificateList": ([str], True),
        "Tags": (Tags, False),
    }


class UserAccessLoggingSettings(AWSObject):
    """
    `UserAccessLoggingSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspacesweb-useraccessloggingsettings.html>`__
    """

    resource_type = "AWS::WorkSpacesWeb::UserAccessLoggingSettings"

    props: PropsDictType = {
        "KinesisStreamArn": (str, True),
        "Tags": (Tags, False),
    }


class CookieSpecification(AWSProperty):
    """
    `CookieSpecification <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-workspacesweb-usersettings-cookiespecification.html>`__
    """

    props: PropsDictType = {
        "Domain": (str, True),
        "Name": (str, False),
        "Path": (str, False),
    }


class CookieSynchronizationConfiguration(AWSProperty):
    """
    `CookieSynchronizationConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-workspacesweb-usersettings-cookiesynchronizationconfiguration.html>`__
    """

    props: PropsDictType = {
        "Allowlist": ([CookieSpecification], True),
        "Blocklist": ([CookieSpecification], False),
    }


class UserSettings(AWSObject):
    """
    `UserSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspacesweb-usersettings.html>`__
    """

    resource_type = "AWS::WorkSpacesWeb::UserSettings"

    props: PropsDictType = {
        "AdditionalEncryptionContext": (dict, False),
        "CookieSynchronizationConfiguration": (
            CookieSynchronizationConfiguration,
            False,
        ),
        "CopyAllowed": (str, True),
        "CustomerManagedKey": (str, False),
        "DisconnectTimeoutInMinutes": (double, False),
        "DownloadAllowed": (str, True),
        "IdleDisconnectTimeoutInMinutes": (double, False),
        "PasteAllowed": (str, True),
        "PrintAllowed": (str, True),
        "Tags": (Tags, False),
        "UploadAllowed": (str, True),
    }



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags
from .validators import boolean, integer


class ChannelTargetInfo(AWSProperty):
    """
    `ChannelTargetInfo <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ssmcontacts-plan-channeltargetinfo.html>`__
    """

    props: PropsDictType = {
        "ChannelId": (str, True),
        "RetryIntervalInMinutes": (integer, True),
    }


class ContactTargetInfo(AWSProperty):
    """
    `ContactTargetInfo <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ssmcontacts-plan-contacttargetinfo.html>`__
    """

    props: PropsDictType = {
        "ContactId": (str, True),
        "IsEssential": (boolean, True),
    }


class Targets(AWSProperty):
    """
    `Targets <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ssmcontacts-plan-targets.html>`__
    """

    props: PropsDictType = {
        "ChannelTargetInfo": (ChannelTargetInfo, False),
        "ContactTargetInfo": (ContactTargetInfo, False),
    }


class Stage(AWSProperty):
    """
    `Stage <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ssmcontacts-plan-stage.html>`__
    """

    props: PropsDictType = {
        "DurationInMinutes": (integer, True),
        "Targets": ([Targets], False),
    }


class Contact(AWSObject):
    """
    `Contact <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ssmcontacts-contact.html>`__
    """

    resource_type = "AWS::SSMContacts::Contact"

    props: PropsDictType = {
        "Alias": (str, True),
        "DisplayName": (str, True),
        "Plan": ([Stage], False),
        "Type": (str, True),
    }


class ContactChannel(AWSObject):
    """
    `ContactChannel <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ssmcontacts-contactchannel.html>`__
    """

    resource_type = "AWS::SSMContacts::ContactChannel"

    props: PropsDictType = {
        "ChannelAddress": (str, True),
        "ChannelName": (str, True),
        "ChannelType": (str, True),
        "ContactId": (str, True),
        "DeferActivation": (boolean, False),
    }


class Plan(AWSObject):
    """
    `Plan <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ssmcontacts-plan.html>`__
    """

    resource_type = "AWS::SSMContacts::Plan"

    props: PropsDictType = {
        "ContactId": (str, True),
        "RotationIds": ([str], False),
        "Stages": ([Stage], False),
    }


class MonthlySetting(AWSProperty):
    """
    `MonthlySetting <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ssmcontacts-rotation-monthlysetting.html>`__
    """

    props: PropsDictType = {
        "DayOfMonth": (integer, True),
        "HandOffTime": (str, True),
    }


class CoverageTime(AWSProperty):
    """
    `CoverageTime <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ssmcontacts-rotation-coveragetime.html>`__
    """

    props: PropsDictType = {
        "EndTime": (str, True),
        "StartTime": (str, True),
    }


class ShiftCoverage(AWSProperty):
    """
    `ShiftCoverage <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ssmcontacts-rotation-shiftcoverage.html>`__
    """

    props: PropsDictType = {
        "CoverageTimes": ([CoverageTime], True),
        "DayOfWeek": (str, True),
    }


class WeeklySetting(AWSProperty):
    """
    `WeeklySetting <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ssmcontacts-rotation-weeklysetting.html>`__
    """

    props: PropsDictType = {
        "DayOfWeek": (str, True),
        "HandOffTime": (str, True),
    }


class RecurrenceSettings(AWSProperty):
    """
    `RecurrenceSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ssmcontacts-rotation-recurrencesettings.html>`__
    """

    props: PropsDictType = {
        "DailySettings": ([str], False),
        "MonthlySettings": ([MonthlySetting], False),
        "NumberOfOnCalls": (integer, True),
        "RecurrenceMultiplier": (integer, True),
        "ShiftCoverages": ([ShiftCoverage], False),
        "WeeklySettings": ([WeeklySetting], False),
    }


class Rotation(AWSObject):
    """
    `Rotation <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ssmcontacts-rotation.html>`__
    """

    resource_type = "AWS::SSMContacts::Rotation"

    props: PropsDictType = {
        "ContactIds": ([str], True),
        "Name": (str, True),
        "Recurrence": (RecurrenceSettings, True),
        "StartTime": (str, True),
        "Tags": (Tags, False),
        "TimeZoneId": (str, True),
    }



import unittest

import troposphere.guardduty as guardduty


class TestGuardDuty(unittest.TestCase):
    def test_guardduty_detector(self):
        detector = guardduty.Detector("detector")

        with self.assertRaises(ValueError):
            detector.to_dict()

        detector = guardduty.Detector("detector", Enable=True)

        result = detector.to_dict()
        self.assertEqual(result["Type"], "AWS::GuardDuty::Detector")

    def test_guardduty_ipset(self):
        ipset = guardduty.IPSet("ipset")

        with self.assertRaises(ValueError):
            ipset.to_dict()

        ipset = guardduty.IPSet(
            "ipset",
            Activate=True,
            DetectorId="aaaabbbbccccddddeeeeffff11112222",
            Format="TXT",
            Location="http://example.com/ipset.txt",
            Name="guardduty-name",
        )

        result = ipset.to_dict()

        self.assertEqual(result["Type"], "AWS::GuardDuty::IPSet")

    def test_guardduty_threatintelset(self):
        threat_intel_set = guardduty.ThreatIntelSet("threatintelset")

        with self.assertRaises(ValueError):
            threat_intel_set.to_dict()

        threat_intel_set = guardduty.ThreatIntelSet(
            "threatintelset",
            Activate=True,
            DetectorId="aaaabbbbccccddddeeeeffff11112222",
            Format="TXT",
            Location="http://example.com/threatintelset.txt",
            Name="guardduty-name",
        )

        result = threat_intel_set.to_dict()
        self.assertEqual(result["Type"], "AWS::GuardDuty::ThreatIntelSet")



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags
from .validators import boolean, double, integer
from .validators.eks import VALID_TAINT_EFFECT  # noqa: F401
from .validators.eks import (
    validate_cluster_logging,
    validate_taint_effect,
    validate_taint_key,
    validate_taint_value,
)


class AccessScope(AWSProperty):
    """
    `AccessScope <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-eks-accessentry-accessscope.html>`__
    """

    props: PropsDictType = {
        "Namespaces": ([str], False),
        "Type": (str, True),
    }


class AccessPolicy(AWSProperty):
    """
    `AccessPolicy <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-eks-accessentry-accesspolicy.html>`__
    """

    props: PropsDictType = {
        "AccessScope": (AccessScope, True),
        "PolicyArn": (str, True),
    }


class AccessEntry(AWSObject):
    """
    `AccessEntry <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eks-accessentry.html>`__
    """

    resource_type = "AWS::EKS::AccessEntry"

    props: PropsDictType = {
        "AccessPolicies": ([AccessPolicy], False),
        "ClusterName": (str, True),
        "KubernetesGroups": ([str], False),
        "PrincipalArn": (str, True),
        "Tags": (Tags, False),
        "Type": (str, False),
        "Username": (str, False),
    }


class Addon(AWSObject):
    """
    `Addon <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eks-addon.html>`__
    """

    resource_type = "AWS::EKS::Addon"

    props: PropsDictType = {
        "AddonName": (str, True),
        "AddonVersion": (str, False),
        "ClusterName": (str, True),
        "ConfigurationValues": (str, False),
        "PreserveOnDelete": (boolean, False),
        "ResolveConflicts": (str, False),
        "ServiceAccountRoleArn": (str, False),
        "Tags": (Tags, False),
    }


class AccessConfig(AWSProperty):
    """
    `AccessConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-eks-cluster-accessconfig.html>`__
    """

    props: PropsDictType = {
        "AuthenticationMode": (str, False),
        "BootstrapClusterCreatorAdminPermissions": (boolean, False),
    }


class Provider(AWSProperty):
    """
    `Provider <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-eks-cluster-provider.html>`__
    """

    props: PropsDictType = {
        "KeyArn": (str, False),
    }


class EncryptionConfig(AWSProperty):
    """
    `EncryptionConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-eks-cluster-encryptionconfig.html>`__
    """

    props: PropsDictType = {
        "Provider": (Provider, False),
        "Resources": ([str], False),
    }


class KubernetesNetworkConfig(AWSProperty):
    """
    `KubernetesNetworkConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-eks-cluster-kubernetesnetworkconfig.html>`__
    """

    props: PropsDictType = {
        "IpFamily": (str, False),
        "ServiceIpv4Cidr": (str, False),
        "ServiceIpv6Cidr": (str, False),
    }


class LoggingTypeConfig(AWSProperty):
    """
    `LoggingTypeConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-eks-cluster-loggingtypeconfig.html>`__
    """

    props: PropsDictType = {
        "Type": (str, False),
    }


class ClusterLogging(AWSProperty):
    """
    `ClusterLogging <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-eks-cluster-clusterlogging.html>`__
    """

    props: PropsDictType = {
        "EnabledTypes": ([LoggingTypeConfig], False),
    }

    def validate(self):
        validate_cluster_logging(self)


class Logging(AWSProperty):
    """
    `Logging <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-eks-cluster-logging.html>`__
    """

    props: PropsDictType = {
        "ClusterLogging": (ClusterLogging, False),
    }


class ControlPlanePlacement(AWSProperty):
    """
    `ControlPlanePlacement <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-eks-cluster-controlplaneplacement.html>`__
    """

    props: PropsDictType = {
        "GroupName": (str, False),
    }


class OutpostConfig(AWSProperty):
    """
    `OutpostConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-eks-cluster-outpostconfig.html>`__
    """

    props: PropsDictType = {
        "ControlPlaneInstanceType": (str, True),
        "ControlPlanePlacement": (ControlPlanePlacement, False),
        "OutpostArns": ([str], True),
    }


class ResourcesVpcConfig(AWSProperty):
    """
    `ResourcesVpcConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-eks-cluster-resourcesvpcconfig.html>`__
    """

    props: PropsDictType = {
        "EndpointPrivateAccess": (boolean, False),
        "EndpointPublicAccess": (boolean, False),
        "PublicAccessCidrs": ([str], False),
        "SecurityGroupIds": ([str], False),
        "SubnetIds": ([str], True),
    }


class Cluster(AWSObject):
    """
    `Cluster <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eks-cluster.html>`__
    """

    resource_type = "AWS::EKS::Cluster"

    props: PropsDictType = {
        "AccessConfig": (AccessConfig, False),
        "EncryptionConfig": ([EncryptionConfig], False),
        "KubernetesNetworkConfig": (KubernetesNetworkConfig, False),
        "Logging": (Logging, False),
        "Name": (str, False),
        "OutpostConfig": (OutpostConfig, False),
        "ResourcesVpcConfig": (ResourcesVpcConfig, True),
        "RoleArn": (str, True),
        "Tags": (Tags, False),
        "Version": (str, False),
    }


class Label(AWSProperty):
    """
    `Label <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-eks-fargateprofile-label.html>`__
    """

    props: PropsDictType = {
        "Key": (str, True),
        "Value": (str, True),
    }


class Selector(AWSProperty):
    """
    `Selector <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-eks-fargateprofile-selector.html>`__
    """

    props: PropsDictType = {
        "Labels": ([Label], False),
        "Namespace": (str, True),
    }


class FargateProfile(AWSObject):
    """
    `FargateProfile <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eks-fargateprofile.html>`__
    """

    resource_type = "AWS::EKS::FargateProfile"

    props: PropsDictType = {
        "ClusterName": (str, True),
        "FargateProfileName": (str, False),
        "PodExecutionRoleArn": (str, True),
        "Selectors": ([Selector], True),
        "Subnets": ([str], False),
        "Tags": (Tags, False),
    }


class RequiredClaim(AWSProperty):
    """
    `RequiredClaim <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-eks-identityproviderconfig-requiredclaim.html>`__
    """

    props: PropsDictType = {
        "Key": (str, True),
        "Value": (str, True),
    }


class OidcIdentityProviderConfig(AWSProperty):
    """
    `OidcIdentityProviderConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-eks-identityproviderconfig-oidcidentityproviderconfig.html>`__
    """

    props: PropsDictType = {
        "ClientId": (str, True),
        "GroupsClaim": (str, False),
        "GroupsPrefix": (str, False),
        "IssuerUrl": (str, True),
        "RequiredClaims": ([RequiredClaim], False),
        "UsernameClaim": (str, False),
        "UsernamePrefix": (str, False),
    }


class IdentityProviderConfig(AWSObject):
    """
    `IdentityProviderConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eks-identityproviderconfig.html>`__
    """

    resource_type = "AWS::EKS::IdentityProviderConfig"

    props: PropsDictType = {
        "ClusterName": (str, True),
        "IdentityProviderConfigName": (str, False),
        "Oidc": (OidcIdentityProviderConfig, False),
        "Tags": (Tags, False),
        "Type": (str, True),
    }


class LaunchTemplateSpecification(AWSProperty):
    """
    `LaunchTemplateSpecification <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-eks-nodegroup-launchtemplatespecification.html>`__
    """

    props: PropsDictType = {
        "Id": (str, False),
        "Name": (str, False),
        "Version": (str, False),
    }


class RemoteAccess(AWSProperty):
    """
    `RemoteAccess <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-eks-nodegroup-remoteaccess.html>`__
    """

    props: PropsDictType = {
        "Ec2SshKey": (str, True),
        "SourceSecurityGroups": ([str], False),
    }


class ScalingConfig(AWSProperty):
    """
    `ScalingConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-eks-nodegroup-scalingconfig.html>`__
    """

    props: PropsDictType = {
        "DesiredSize": (integer, False),
        "MaxSize": (integer, False),
        "MinSize": (integer, False),
    }


class Taint(AWSProperty):
    """
    `Taint <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-eks-nodegroup-taint.html>`__
    """

    props: PropsDictType = {
        "Effect": (validate_taint_effect, False),
        "Key": (validate_taint_key, False),
        "Value": (validate_taint_value, False),
    }


class UpdateConfig(AWSProperty):
    """
    `UpdateConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-eks-nodegroup-updateconfig.html>`__
    """

    props: PropsDictType = {
        "MaxUnavailable": (double, False),
        "MaxUnavailablePercentage": (double, False),
    }


class Nodegroup(AWSObject):
    """
    `Nodegroup <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eks-nodegroup.html>`__
    """

    resource_type = "AWS::EKS::Nodegroup"

    props: PropsDictType = {
        "AmiType": (str, False),
        "CapacityType": (str, False),
        "ClusterName": (str, True),
        "DiskSize": (integer, False),
        "ForceUpdateEnabled": (boolean, False),
        "InstanceTypes": ([str], False),
        "Labels": (dict, False),
        "LaunchTemplate": (LaunchTemplateSpecification, False),
        "NodeRole": (str, True),
        "NodegroupName": (str, False),
        "ReleaseVersion": (str, False),
        "RemoteAccess": (RemoteAccess, False),
        "ScalingConfig": (ScalingConfig, False),
        "Subnets": ([str], True),
        "Tags": (dict, False),
        "Taints": ([Taint], False),
        "UpdateConfig": (UpdateConfig, False),
        "Version": (str, False),
    }


class PodIdentityAssociation(AWSObject):
    """
    `PodIdentityAssociation <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eks-podidentityassociation.html>`__
    """

    resource_type = "AWS::EKS::PodIdentityAssociation"

    props: PropsDictType = {
        "ClusterName": (str, True),
        "Namespace": (str, True),
        "RoleArn": (str, True),
        "ServiceAccount": (str, True),
        "Tags": (Tags, False),
    }



import unittest

from troposphere.config import ONE_HOUR, SourceDetails


class TestConfig(unittest.TestCase):
    def test_SourceDetails(self):
        SourceDetails(
            EventSource="esource",
            MaximumExecutionFrequency=ONE_HOUR,
            MessageType="mtype",
        ).to_dict()

    def test_invalid_SourceDetails_MaximumExecutionFrequency(self):
        with self.assertRaises(ValueError):
            SourceDetails(
                EventSource="esource",
                MaximumExecutionFrequency="foo",
                MessageType="mtype",
            ).to_dict()


if __name__ == "__main__":
    unittest.main()



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, PropsDictType


class Link(AWSObject):
    """
    `Link <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-oam-link.html>`__
    """

    resource_type = "AWS::Oam::Link"

    props: PropsDictType = {
        "LabelTemplate": (str, False),
        "ResourceTypes": ([str], True),
        "SinkIdentifier": (str, True),
        "Tags": (dict, False),
    }


class Sink(AWSObject):
    """
    `Sink <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-oam-sink.html>`__
    """

    resource_type = "AWS::Oam::Sink"

    props: PropsDictType = {
        "Name": (str, True),
        "Policy": (dict, False),
        "Tags": (dict, False),
    }



import unittest

from troposphere import Parameter, Ref, Template
from troposphere.s3 import AccelerateConfiguration, Bucket, Private


class TestBucketTemplate(unittest.TestCase):
    def test_bucket_template(self):
        title = "PlaylistsFailoverS3Bucket"
        template = Template()
        Bucket(
            title,
            template,
            AccessControl=Private,
            BucketName="test-bucket",
        )
        self.assertIn(title, template.resources)


class TestBucket(unittest.TestCase):
    def test_bucket_accesscontrol(self):
        Bucket("b", AccessControl="AuthenticatedRead").validate()

    def test_bucket_accesscontrol_bad_string(self):
        with self.assertRaises(ValueError):
            Bucket("b", AccessControl="FooBar").validate()

    def test_bucket_accesscontrol_bad_type(self):
        with self.assertRaises(TypeError):
            Bucket("b", AccessControl=123).validate()

    def test_bucket_accesscontrol_ref(self):
        bucket_acl = Parameter("acl", Type="String", Default="Private")
        Bucket("b", AccessControl=Ref(bucket_acl)).validate()


class TestS3AccelerateConfiguration(unittest.TestCase):
    def test_accelerate_configuration_enabled(self):
        ac = AccelerateConfiguration(
            AccelerationStatus="Enabled",
        )
        self.assertEqual("Enabled", ac.AccelerationStatus)

    def test_accelerate_configuration_suspended(self):
        ac = AccelerateConfiguration(
            AccelerationStatus="Suspended",
        )
        self.assertEqual("Suspended", ac.AccelerationStatus)

    def test_accelerate_configuration_invalid_value(self):
        with self.assertRaises(ValueError):
            AccelerateConfiguration(AccelerationStatus="Invalid Value")

    def test_s3_bucket_accelerate_configuration(self):
        t = Template()
        ac = AccelerateConfiguration(AccelerationStatus="Enabled")

        b = Bucket("s3Bucket", AccelerateConfiguration=ac)
        t.add_resource(b)
        output = t.to_json()
        self.assertIn('"AccelerationStatus": "Enabled"', output)


if __name__ == "__main__":
    unittest.main()



import unittest

from troposphere import Output, Ref, Sub, Template, s3
from troposphere.cloudformation import WaitCondition

s3_bucket_yaml = """\
Description: S3 Bucket Example
Outputs:
  BucketName:
    Description: Name of S3 bucket to hold website content
    Value: !Ref 'S3Bucket'
Resources:
  S3Bucket:
    Properties:
      AccessControl: PublicRead
    Type: AWS::S3::Bucket
"""

cond_string = """My
special multiline
Handle"""

cond_normal = """Resources:
  MyWaitCondition:
    Properties:
      Handle: !Sub "My\\nspecial multiline\\nHandle"
      Timeout: '30'
    Type: AWS::CloudFormation::WaitCondition
"""

cond_long = """Resources:
  MyWaitCondition:
    Properties:
      Handle:
        Fn::Sub: "My\\nspecial multiline\\nHandle"
      Timeout: '30'
    Type: AWS::CloudFormation::WaitCondition
"""

cond_clean = """Resources:
  MyWaitCondition:
    Properties:
      Handle: !Sub |-
        My
        special multiline
        Handle
      Timeout: '30'
    Type: AWS::CloudFormation::WaitCondition
"""


class TestYAML(unittest.TestCase):
    def test_s3_bucket(self):
        t = Template()
        t.set_description("S3 Bucket Example")
        s3bucket = t.add_resource(
            s3.Bucket(
                "S3Bucket",
                AccessControl=s3.PublicRead,
            )
        )
        t.add_output(
            Output(
                "BucketName",
                Value=Ref(s3bucket),
                Description="Name of S3 bucket to hold website content",
            )
        )
        self.assertEqual(s3_bucket_yaml, t.to_yaml())

    def test_yaml_long_form(self):
        t = Template()
        t.add_resource(
            WaitCondition("MyWaitCondition", Timeout=30, Handle=Sub(cond_string))
        )
        self.assertEqual(cond_normal, t.to_yaml())
        self.assertEqual(cond_long, t.to_yaml(long_form=True))
        self.assertEqual(cond_long, t.to_yaml(False, True))
        self.assertEqual(cond_clean, t.to_yaml(clean_up=True))
        self.assertEqual(cond_clean, t.to_yaml(True))



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType
from .validators import boolean


class ColumnWildcard(AWSProperty):
    """
    `ColumnWildcard <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-principalpermissions-columnwildcard.html>`__
    """

    props: PropsDictType = {
        "ExcludedColumnNames": ([str], False),
    }


class RowFilter(AWSProperty):
    """
    `RowFilter <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-datacellsfilter-rowfilter.html>`__
    """

    props: PropsDictType = {
        "AllRowsWildcard": (dict, False),
        "FilterExpression": (str, False),
    }


class DataCellsFilter(AWSObject):
    """
    `DataCellsFilter <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lakeformation-datacellsfilter.html>`__
    """

    resource_type = "AWS::LakeFormation::DataCellsFilter"

    props: PropsDictType = {
        "ColumnNames": ([str], False),
        "ColumnWildcard": (ColumnWildcard, False),
        "DatabaseName": (str, True),
        "Name": (str, True),
        "RowFilter": (RowFilter, False),
        "TableCatalogId": (str, True),
        "TableName": (str, True),
    }


class DataLakePrincipal(AWSProperty):
    """
    `DataLakePrincipal <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-principalpermissions-datalakeprincipal.html>`__
    """

    props: PropsDictType = {
        "DataLakePrincipalIdentifier": (str, False),
    }


class DataLakeSettings(AWSObject):
    """
    `DataLakeSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lakeformation-datalakesettings.html>`__
    """

    resource_type = "AWS::LakeFormation::DataLakeSettings"

    props: PropsDictType = {
        "Admins": ([DataLakePrincipal], False),
        "AllowExternalDataFiltering": (boolean, False),
        "AllowFullTableExternalDataAccess": (boolean, False),
        "AuthorizedSessionTagValueList": ([str], False),
        "CreateDatabaseDefaultPermissions": ([], False),
        "CreateTableDefaultPermissions": ([], False),
        "ExternalDataFilteringAllowList": ([], False),
        "MutationType": (str, False),
        "Parameters": (dict, False),
        "TrustedResourceOwners": ([str], False),
    }


class DatabaseResource(AWSProperty):
    """
    `DatabaseResource <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-tagassociation-databaseresource.html>`__
    """

    props: PropsDictType = {
        "CatalogId": (str, True),
        "Name": (str, True),
    }


class PermissionsDataLocationResource(AWSProperty):
    """
    `PermissionsDataLocationResource <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-permissions-datalocationresource.html>`__
    """

    props: PropsDictType = {
        "CatalogId": (str, False),
        "S3Resource": (str, False),
    }


class TableResource(AWSProperty):
    """
    `TableResource <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-tagassociation-tableresource.html>`__
    """

    props: PropsDictType = {
        "CatalogId": (str, True),
        "DatabaseName": (str, True),
        "Name": (str, False),
        "TableWildcard": (dict, False),
    }


class TableWithColumnsResource(AWSProperty):
    """
    `TableWithColumnsResource <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-principalpermissions-tablewithcolumnsresource.html>`__
    """

    props: PropsDictType = {
        "CatalogId": (str, True),
        "ColumnNames": ([str], False),
        "ColumnWildcard": (ColumnWildcard, False),
        "DatabaseName": (str, True),
        "Name": (str, True),
    }


class ResourceProperty(AWSProperty):
    """
    `ResourceProperty <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-permissions-resource.html>`__
    """

    props: PropsDictType = {
        "DataLocationResource": (PermissionsDataLocationResource, False),
        "DatabaseResource": (DatabaseResource, False),
        "TableResource": (TableResource, False),
        "TableWithColumnsResource": (TableWithColumnsResource, False),
    }


class Permissions(AWSObject):
    """
    `Permissions <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lakeformation-permissions.html>`__
    """

    resource_type = "AWS::LakeFormation::Permissions"

    props: PropsDictType = {
        "DataLakePrincipal": (DataLakePrincipal, True),
        "Permissions": ([str], False),
        "PermissionsWithGrantOption": ([str], False),
        "Resource": (ResourceProperty, True),
    }


class DataCellsFilterResource(AWSProperty):
    """
    `DataCellsFilterResource <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-principalpermissions-datacellsfilterresource.html>`__
    """

    props: PropsDictType = {
        "DatabaseName": (str, True),
        "Name": (str, True),
        "TableCatalogId": (str, True),
        "TableName": (str, True),
    }


class DataLocationResource(AWSProperty):
    """
    `DataLocationResource <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-principalpermissions-datalocationresource.html>`__
    """

    props: PropsDictType = {
        "CatalogId": (str, True),
        "ResourceArn": (str, True),
    }


class LFTagKeyResource(AWSProperty):
    """
    `LFTagKeyResource <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-principalpermissions-lftagkeyresource.html>`__
    """

    props: PropsDictType = {
        "CatalogId": (str, True),
        "TagKey": (str, True),
        "TagValues": ([str], True),
    }


class LFTag(AWSProperty):
    """
    `LFTag <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-principalpermissions-lftag.html>`__
    """

    props: PropsDictType = {
        "TagKey": (str, False),
        "TagValues": ([str], False),
    }


class LFTagPolicyResource(AWSProperty):
    """
    `LFTagPolicyResource <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-principalpermissions-lftagpolicyresource.html>`__
    """

    props: PropsDictType = {
        "CatalogId": (str, True),
        "Expression": ([LFTag], True),
        "ResourceType": (str, True),
    }


class PrincipalResource(AWSProperty):
    """
    `PrincipalResource <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-principalpermissions-resource.html>`__
    """

    props: PropsDictType = {
        "Catalog": (dict, False),
        "DataCellsFilter": (DataCellsFilterResource, False),
        "DataLocation": (DataLocationResource, False),
        "Database": (DatabaseResource, False),
        "LFTag": (LFTagKeyResource, False),
        "LFTagPolicy": (LFTagPolicyResource, False),
        "Table": (TableResource, False),
        "TableWithColumns": (TableWithColumnsResource, False),
    }


class PrincipalPermissions(AWSObject):
    """
    `PrincipalPermissions <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lakeformation-principalpermissions.html>`__
    """

    resource_type = "AWS::LakeFormation::PrincipalPermissions"

    props: PropsDictType = {
        "Catalog": (str, False),
        "Permissions": ([str], True),
        "PermissionsWithGrantOption": ([str], True),
        "Principal": (DataLakePrincipal, True),
        "Resource": (PrincipalResource, True),
    }


class Resource(AWSObject):
    """
    `Resource <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lakeformation-resource.html>`__
    """

    resource_type = "AWS::LakeFormation::Resource"

    props: PropsDictType = {
        "HybridAccessEnabled": (boolean, False),
        "ResourceArn": (str, True),
        "RoleArn": (str, False),
        "UseServiceLinkedRole": (boolean, True),
        "WithFederation": (boolean, False),
    }


class Tag(AWSObject):
    """
    `Tag <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lakeformation-tag.html>`__
    """

    resource_type = "AWS::LakeFormation::Tag"

    props: PropsDictType = {
        "CatalogId": (str, False),
        "TagKey": (str, True),
        "TagValues": ([str], True),
    }


class LFTagPair(AWSProperty):
    """
    `LFTagPair <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-tagassociation-lftagpair.html>`__
    """

    props: PropsDictType = {
        "CatalogId": (str, True),
        "TagKey": (str, True),
        "TagValues": ([str], True),
    }


class TagAssociationTableWithColumnsResource(AWSProperty):
    """
    `TagAssociationTableWithColumnsResource <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-tagassociation-tablewithcolumnsresource.html>`__
    """

    props: PropsDictType = {
        "CatalogId": (str, True),
        "ColumnNames": ([str], True),
        "DatabaseName": (str, True),
        "Name": (str, True),
    }


class TagAssociationResource(AWSProperty):
    """
    `TagAssociationResource <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-tagassociation-resource.html>`__
    """

    props: PropsDictType = {
        "Catalog": (dict, False),
        "Database": (DatabaseResource, False),
        "Table": (TableResource, False),
        "TableWithColumns": (TagAssociationTableWithColumnsResource, False),
    }


class TagAssociation(AWSObject):
    """
    `TagAssociation <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lakeformation-tagassociation.html>`__
    """

    resource_type = "AWS::LakeFormation::TagAssociation"

    props: PropsDictType = {
        "LFTags": ([LFTagPair], True),
        "Resource": (TagAssociationResource, True),
    }


class PrincipalPermissionsProperty(AWSProperty):
    """
    `PrincipalPermissionsProperty <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-datalakesettings-principalpermissions.html>`__
    """

    props: PropsDictType = {
        "Permissions": ([str], True),
        "Principal": (DataLakePrincipal, True),
    }


class TableWildcard(AWSProperty):
    """
    `TableWildcard <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lakeformation-permissions-tablewildcard.html>`__
    """

    props: PropsDictType = {}



import troposphere.elasticloadbalancingv2 as elb
from troposphere import Parameter, Template


def main():
    template = Template()

    subnetA = template.add_parameter(Parameter("subnetA", Type="String"))
    subnetB = template.add_parameter(Parameter("subnetB", Type="String"))

    alb = template.add_resource(
        elb.LoadBalancer(
            "ALB",
            Scheme="internet-facing",
            Subnets=[subnetA.ref(), subnetB.ref()],
        )
    )

    listener = template.add_resource(
        elb.Listener(
            "Listener",
            Port="80",
            Protocol="HTTP",
            LoadBalancerArn=alb.ref(),
            DefaultActions=[
                elb.Action(
                    Type="fixed-response",
                    FixedResponseConfig=elb.FixedResponseConfig(
                        StatusCode="200",
                        MessageBody=(
                            "This is a fixed response for the default " "ALB action"
                        ),
                        ContentType="text/plain",
                    ),
                )
            ],
        )
    )

    template.add_resource(
        [
            elb.ListenerRule(
                "ListenerRuleApi",
                ListenerArn=listener.ref(),
                Conditions=[
                    elb.Condition(Field="host-header", Values=["api.example.com"]),
                    elb.Condition(
                        Field="http-header",
                        HttpHeaderConfig=elb.HttpHeaderConfig(
                            HttpHeaderName="X-Action", Values=["Create"]
                        ),
                    ),
                    elb.Condition(
                        Field="path-pattern",
                        PathPatternConfig=elb.PathPatternConfig(Values=["/api/*"]),
                    ),
                    elb.Condition(
                        Field="http-request-method",
                        HttpRequestMethodConfig=elb.HttpRequestMethodConfig(
                            Values=["POST"]
                        ),
                    ),
                ],
                Actions=[
                    elb.ListenerRuleAction(
                        Type="fixed-response",
                        FixedResponseConfig=elb.FixedResponseConfig(
                            StatusCode="200",
                            MessageBody=(
                                "This is a fixed response for any API POST "
                                "request with header X-Action: Create"
                            ),
                            ContentType="text/plain",
                        ),
                    )
                ],
                Priority="10",
            ),
            elb.ListenerRule(
                "ListenerRuleWeb",
                ListenerArn=listener.ref(),
                Conditions=[
                    elb.Condition(
                        Field="host-header",
                        HostHeaderConfig=elb.HostHeaderConfig(
                            Values=["www.example.com"]
                        ),
                    ),
                    elb.Condition(
                        Field="path-pattern",
                        PathPatternConfig=elb.PathPatternConfig(Values=["/web/*"]),
                    ),
                ],
                Actions=[
                    elb.ListenerRuleAction(
                        Type="fixed-response",
                        FixedResponseConfig=elb.FixedResponseConfig(
                            StatusCode="200",
                            MessageBody=(
                                "This is a fixed response for any WEB " "request"
                            ),
                            ContentType="text/plain",
                        ),
                    )
                ],
                Priority="20",
            ),
            elb.ListenerRule(
                "ListenerRuleMetrics",
                ListenerArn=listener.ref(),
                Conditions=[elb.Condition(Field="path-pattern", Values=["/metrics/*"])],
                Actions=[
                    elb.ListenerRuleAction(
                        Type="redirect",
                        RedirectConfig=elb.RedirectConfig(
                            StatusCode="HTTP_301", Protocol="HTTPS", Port="443"
                        ),
                    )
                ],
                Priority="30",
            ),
            elb.ListenerRule(
                "ListenerRuleSourceIp",
                ListenerArn=listener.ref(),
                Conditions=[
                    elb.Condition(
                        Field="source-ip",
                        SourceIpConfig=elb.SourceIpConfig(Values=["52.30.12.16/28"]),
                    )
                ],
                Actions=[
                    elb.ListenerRuleAction(
                        Type="fixed-response",
                        FixedResponseConfig=elb.FixedResponseConfig(
                            StatusCode="200",
                            MessageBody=(
                                "The request came from IP range " "52.30.12.16/28"
                            ),
                            ContentType="text/plain",
                        ),
                    )
                ],
                Priority="40",
            ),
        ]
    )

    print(template.to_json())


if __name__ == "__main__":
    main()



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType
from .validators import boolean, double, integer


class ComponentDependencyRequirement(AWSProperty):
    """
    `ComponentDependencyRequirement <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-greengrassv2-componentversion-componentdependencyrequirement.html>`__
    """

    props: PropsDictType = {
        "DependencyType": (str, False),
        "VersionRequirement": (str, False),
    }


class ComponentPlatform(AWSProperty):
    """
    `ComponentPlatform <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-greengrassv2-componentversion-componentplatform.html>`__
    """

    props: PropsDictType = {
        "Attributes": (dict, False),
        "Name": (str, False),
    }


class LambdaEventSource(AWSProperty):
    """
    `LambdaEventSource <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-greengrassv2-componentversion-lambdaeventsource.html>`__
    """

    props: PropsDictType = {
        "Topic": (str, False),
        "Type": (str, False),
    }


class LambdaDeviceMount(AWSProperty):
    """
    `LambdaDeviceMount <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-greengrassv2-componentversion-lambdadevicemount.html>`__
    """

    props: PropsDictType = {
        "AddGroupOwner": (boolean, False),
        "Path": (str, False),
        "Permission": (str, False),
    }


class LambdaVolumeMount(AWSProperty):
    """
    `LambdaVolumeMount <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-greengrassv2-componentversion-lambdavolumemount.html>`__
    """

    props: PropsDictType = {
        "AddGroupOwner": (boolean, False),
        "DestinationPath": (str, False),
        "Permission": (str, False),
        "SourcePath": (str, False),
    }


class LambdaContainerParams(AWSProperty):
    """
    `LambdaContainerParams <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-greengrassv2-componentversion-lambdacontainerparams.html>`__
    """

    props: PropsDictType = {
        "Devices": ([LambdaDeviceMount], False),
        "MemorySizeInKB": (integer, False),
        "MountROSysfs": (boolean, False),
        "Volumes": ([LambdaVolumeMount], False),
    }


class LambdaLinuxProcessParams(AWSProperty):
    """
    `LambdaLinuxProcessParams <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-greengrassv2-componentversion-lambdalinuxprocessparams.html>`__
    """

    props: PropsDictType = {
        "ContainerParams": (LambdaContainerParams, False),
        "IsolationMode": (str, False),
    }


class LambdaExecutionParameters(AWSProperty):
    """
    `LambdaExecutionParameters <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-greengrassv2-componentversion-lambdaexecutionparameters.html>`__
    """

    props: PropsDictType = {
        "EnvironmentVariables": (dict, False),
        "EventSources": ([LambdaEventSource], False),
        "ExecArgs": ([str], False),
        "InputPayloadEncodingType": (str, False),
        "LinuxProcessParams": (LambdaLinuxProcessParams, False),
        "MaxIdleTimeInSeconds": (integer, False),
        "MaxInstancesCount": (integer, False),
        "MaxQueueSize": (integer, False),
        "Pinned": (boolean, False),
        "StatusTimeoutInSeconds": (integer, False),
        "TimeoutInSeconds": (integer, False),
    }


class LambdaFunctionRecipeSource(AWSProperty):
    """
    `LambdaFunctionRecipeSource <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-greengrassv2-componentversion-lambdafunctionrecipesource.html>`__
    """

    props: PropsDictType = {
        "ComponentDependencies": (dict, False),
        "ComponentLambdaParameters": (LambdaExecutionParameters, False),
        "ComponentName": (str, False),
        "ComponentPlatforms": ([ComponentPlatform], False),
        "ComponentVersion": (str, False),
        "LambdaArn": (str, False),
    }


class ComponentVersion(AWSObject):
    """
    `ComponentVersion <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-greengrassv2-componentversion.html>`__
    """

    resource_type = "AWS::GreengrassV2::ComponentVersion"

    props: PropsDictType = {
        "InlineRecipe": (str, False),
        "LambdaFunction": (LambdaFunctionRecipeSource, False),
        "Tags": (dict, False),
    }


class ComponentConfigurationUpdate(AWSProperty):
    """
    `ComponentConfigurationUpdate <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-greengrassv2-deployment-componentconfigurationupdate.html>`__
    """

    props: PropsDictType = {
        "Merge": (str, False),
        "Reset": ([str], False),
    }


class SystemResourceLimits(AWSProperty):
    """
    `SystemResourceLimits <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-greengrassv2-deployment-systemresourcelimits.html>`__
    """

    props: PropsDictType = {
        "Cpus": (double, False),
        "Memory": (integer, False),
    }


class ComponentRunWith(AWSProperty):
    """
    `ComponentRunWith <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-greengrassv2-deployment-componentrunwith.html>`__
    """

    props: PropsDictType = {
        "PosixUser": (str, False),
        "SystemResourceLimits": (SystemResourceLimits, False),
        "WindowsUser": (str, False),
    }


class ComponentDeploymentSpecification(AWSProperty):
    """
    `ComponentDeploymentSpecification <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-greengrassv2-deployment-componentdeploymentspecification.html>`__
    """

    props: PropsDictType = {
        "ComponentVersion": (str, False),
        "ConfigurationUpdate": (ComponentConfigurationUpdate, False),
        "RunWith": (ComponentRunWith, False),
    }


class IoTJobAbortCriteria(AWSProperty):
    """
    `IoTJobAbortCriteria <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-greengrassv2-deployment-iotjobabortcriteria.html>`__
    """

    props: PropsDictType = {
        "Action": (str, True),
        "FailureType": (str, True),
        "MinNumberOfExecutedThings": (integer, True),
        "ThresholdPercentage": (double, True),
    }


class IoTJobAbortConfig(AWSProperty):
    """
    `IoTJobAbortConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-greengrassv2-deployment-iotjobabortconfig.html>`__
    """

    props: PropsDictType = {
        "CriteriaList": ([IoTJobAbortCriteria], True),
    }


class IoTJobRateIncreaseCriteria(AWSProperty):
    props: PropsDictType = {
        "NumberOfNotifiedThings": (integer, False),
        "NumberOfSucceededThings": (integer, False),
    }


class IoTJobExponentialRolloutRate(AWSProperty):
    """
    `IoTJobExponentialRolloutRate <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-greengrassv2-deployment-iotjobexponentialrolloutrate.html>`__
    """

    props: PropsDictType = {
        "BaseRatePerMinute": (integer, True),
        "IncrementFactor": (double, True),
        "RateIncreaseCriteria": (IoTJobRateIncreaseCriteria, True),
    }


class IoTJobExecutionsRolloutConfig(AWSProperty):
    """
    `IoTJobExecutionsRolloutConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-greengrassv2-deployment-iotjobexecutionsrolloutconfig.html>`__
    """

    props: PropsDictType = {
        "ExponentialRate": (IoTJobExponentialRolloutRate, False),
        "MaximumPerMinute": (integer, False),
    }


class IoTJobTimeoutConfig(AWSProperty):
    """
    `IoTJobTimeoutConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-greengrassv2-deployment-iotjobtimeoutconfig.html>`__
    """

    props: PropsDictType = {
        "InProgressTimeoutInMinutes": (integer, False),
    }


class DeploymentIoTJobConfiguration(AWSProperty):
    """
    `DeploymentIoTJobConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-greengrassv2-deployment-deploymentiotjobconfiguration.html>`__
    """

    props: PropsDictType = {
        "AbortConfig": (IoTJobAbortConfig, False),
        "JobExecutionsRolloutConfig": (IoTJobExecutionsRolloutConfig, False),
        "TimeoutConfig": (IoTJobTimeoutConfig, False),
    }


class DeploymentComponentUpdatePolicy(AWSProperty):
    """
    `DeploymentComponentUpdatePolicy <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-greengrassv2-deployment-deploymentcomponentupdatepolicy.html>`__
    """

    props: PropsDictType = {
        "Action": (str, False),
        "TimeoutInSeconds": (integer, False),
    }


class DeploymentConfigurationValidationPolicy(AWSProperty):
    """
    `DeploymentConfigurationValidationPolicy <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-greengrassv2-deployment-deploymentconfigurationvalidationpolicy.html>`__
    """

    props: PropsDictType = {
        "TimeoutInSeconds": (integer, False),
    }


class DeploymentPolicies(AWSProperty):
    """
    `DeploymentPolicies <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-greengrassv2-deployment-deploymentpolicies.html>`__
    """

    props: PropsDictType = {
        "ComponentUpdatePolicy": (DeploymentComponentUpdatePolicy, False),
        "ConfigurationValidationPolicy": (
            DeploymentConfigurationValidationPolicy,
            False,
        ),
        "FailureHandlingPolicy": (str, False),
    }


class Deployment(AWSObject):
    """
    `Deployment <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-greengrassv2-deployment.html>`__
    """

    resource_type = "AWS::GreengrassV2::Deployment"

    props: PropsDictType = {
        "Components": (dict, False),
        "DeploymentName": (str, False),
        "DeploymentPolicies": (DeploymentPolicies, False),
        "IotJobConfiguration": (DeploymentIoTJobConfiguration, False),
        "ParentTargetArn": (str, False),
        "Tags": (dict, False),
        "TargetArn": (str, True),
    }



import unittest

from troposphere import Retain
from troposphere.logs import (
    Destination,
    LogGroup,
    ResourcePolicy,
    validate_resource_policy,
)


class TestLogs(unittest.TestCase):
    def test_loggroup_deletionpolicy_is_preserved(self):
        log_group = LogGroup("LogGroupWithDeletionPolicy", DeletionPolicy=Retain)
        self.assertIn("DeletionPolicy", log_group.to_dict())

    def test_loggroup_retention(self):
        for days in [7, "7"]:
            LogGroup(
                "LogGroupWithDeletionPolicy",
                RetentionInDays=days,
            )

        for days in [6, "6"]:
            with self.assertRaises(ValueError):
                LogGroup(
                    "LogGroupWithDeletionPolicy",
                    RetentionInDays=days,
                )

    def test_log_destination(self):
        log_destination = Destination(
            "MyLogDestination",
            DestinationName="destination-name",
            RoleArn="role-arn",
            TargetArn="target-arn",
            DestinationPolicy="destination-policy",
        )
        log_destination_json = log_destination.to_dict()
        self.assertIn("Type", log_destination_json)
        self.assertIn("Properties", log_destination_json)

    def test_validate_resource_policy(self):
        for s in [
            '{ "Version": "2012-10-17", "Statement": [ { "Sid": "Route53LogsToCloudWatchLogs", "Effect": "Allow", "Principal": { "Service": [ "route53.amazonaws.com" ] }, "Action":"logs:PutLogEvents", "Resource": "logArn" } ] }',
            {
                "Version": "2012-10-17",
                "Statement": [
                    {
                        "Sid": "Route53LogsToCloudWatchLogs",
                        "Effect": "Allow",
                        "Principal": {"Service": ["route53.amazonaws.com"]},
                        "Action": "logs:PutLogEvents",
                        "Resource": "logArn",
                    }
                ],
            },
        ]:
            validate_resource_policy(s)
            log_policy = ResourcePolicy(
                "TestLogPolicy", PolicyName="TestLogPolicy", PolicyDocument=s
            )
            expected = log_policy.to_dict()
            properties = expected["Properties"]
            self.assertEqual(properties.get("PolicyDocument"), s)

        for s in ["", "H" * 5121, "TEXT", {}]:
            with self.assertRaises(ValueError):
                validate_resource_policy(s)


if __name__ == "__main__":
    unittest.main()



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags
from .validators import integer
from .validators.macie import (
    findingsfilter_action,
    session_findingpublishingfrequency,
    session_status,
)


class S3WordsList(AWSProperty):
    """
    `S3WordsList <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-macie-allowlist-s3wordslist.html>`__
    """

    props: PropsDictType = {
        "BucketName": (str, True),
        "ObjectKey": (str, True),
    }


class Criteria(AWSProperty):
    """
    `Criteria <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-macie-allowlist-criteria.html>`__
    """

    props: PropsDictType = {
        "Regex": (str, False),
        "S3WordsList": (S3WordsList, False),
    }


class AllowList(AWSObject):
    """
    `AllowList <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-allowlist.html>`__
    """

    resource_type = "AWS::Macie::AllowList"

    props: PropsDictType = {
        "Criteria": (Criteria, True),
        "Description": (str, False),
        "Name": (str, True),
        "Tags": (Tags, False),
    }


class CustomDataIdentifier(AWSObject):
    """
    `CustomDataIdentifier <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-customdataidentifier.html>`__
    """

    resource_type = "AWS::Macie::CustomDataIdentifier"

    props: PropsDictType = {
        "Description": (str, False),
        "IgnoreWords": ([str], False),
        "Keywords": ([str], False),
        "MaximumMatchDistance": (integer, False),
        "Name": (str, True),
        "Regex": (str, True),
        "Tags": (Tags, False),
    }


class CriterionAdditionalProperties(AWSProperty):
    """
    `CriterionAdditionalProperties <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-macie-findingsfilter-criterionadditionalproperties.html>`__
    """

    props: PropsDictType = {
        "eq": ([str], False),
        "gt": (integer, False),
        "gte": (integer, False),
        "lt": (integer, False),
        "lte": (integer, False),
        "neq": ([str], False),
    }


class FindingCriteria(AWSProperty):
    """
    `FindingCriteria <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-macie-findingsfilter-findingcriteria.html>`__
    """

    props: PropsDictType = {
        "Criterion": (dict, False),
    }


class FindingsFilter(AWSObject):
    """
    `FindingsFilter <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-findingsfilter.html>`__
    """

    resource_type = "AWS::Macie::FindingsFilter"

    props: PropsDictType = {
        "Action": (findingsfilter_action, False),
        "Description": (str, False),
        "FindingCriteria": (FindingCriteria, True),
        "Name": (str, True),
        "Position": (integer, False),
        "Tags": (Tags, False),
    }


class Session(AWSObject):
    """
    `Session <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-session.html>`__
    """

    resource_type = "AWS::Macie::Session"

    props: PropsDictType = {
        "FindingPublishingFrequency": (session_findingpublishingfrequency, False),
        "Status": (session_status, False),
    }



import unittest

from troposphere import ImportValue, Parameter, Ref, Sub, Tags, Template
from troposphere.s3 import Filter, Rules, S3Key
from troposphere.serverless import (
    SERVERLESS_TRANSFORM,
    Api,
    ApiEvent,
    ApiFunctionAuth,
    ApiGlobals,
    Auth,
    DeadLetterQueue,
    DeploymentPreference,
    Domain,
    EndpointConfiguration,
    Function,
    FunctionForPackaging,
    FunctionGlobals,
    FunctionUrlConfig,
    Globals,
    HttpApi,
    HttpApiAuth,
    HttpApiDomainConfiguration,
    HttpApiGlobals,
    LayerVersion,
    OAuth2Authorizer,
    ResourcePolicyStatement,
    Route53,
    S3Event,
    S3Location,
    SimpleTable,
    SimpleTableGlobals,
)


class TestServerless(unittest.TestCase):
    def test_exactly_one_code(self):
        serverless_func = Function(
            "SomeHandler",
            Handler="index.handler",
            Runtime="nodejs",
            CodeUri=S3Location(
                Bucket="mybucket",
                Key="mykey",
            ),
            InlineCode="",
        )
        t = Template()
        t.add_resource(serverless_func)
        with self.assertRaises(ValueError):
            t.to_json()

    def test_s3_location(self):
        serverless_func = Function(
            "SomeHandler",
            Handler="index.handler",
            Runtime="nodejs",
            CodeUri=S3Location(
                Bucket="mybucket",
                Key="mykey",
            ),
        )
        t = Template()
        t.add_resource(serverless_func)
        t.to_json()

    def test_tags(self):
        serverless_func = Function(
            "SomeHandler",
            Handler="index.handler",
            Runtime="nodejs",
            CodeUri="s3://bucket/handler.zip",
            Tags=Tags({"Tag1": "TagValue1", "Tag2": "TagValue2"}),
        )
        t = Template()
        t.add_resource(serverless_func)
        t.to_json()

    def test_DLQ(self):
        serverless_func = Function(
            "SomeHandler",
            Handler="index.handler",
            Runtime="nodejs",
            CodeUri="s3://bucket/handler.zip",
            DeadLetterQueue=DeadLetterQueue(
                Type="SNS", TargetArn="arn:aws:sns:us-east-1:000000000000:SampleTopic"
            ),
        )
        t = Template()
        t.add_resource(serverless_func)
        t.to_json()

    def test_required_function(self):
        serverless_func = Function(
            "SomeHandler",
            Handler="index.handler",
            Runtime="nodejs",
            CodeUri="s3://bucket/handler.zip",
        )
        t = Template()
        t.add_resource(serverless_func)
        t.to_json()

    def test_functionurlconfig_oneof(self):
        serverless_func = Function(
            "SomeHandler",
            FunctionUrlConfig=FunctionUrlConfig(
                AuthType="AWS_IAM",
            ),
            Handler="index.handler",
            Runtime="nodejs",
            CodeUri="s3://bucket/handler.zip",
        )
        t = Template()
        t.add_resource(serverless_func)
        t.to_json()

        with self.assertRaises(ValueError):
            serverless_func = Function(
                "SomeHandler",
                FunctionUrlConfig=FunctionUrlConfig(
                    AuthType="foobar",
                ),
                Handler="index.handler",
                Runtime="nodejs",
                CodeUri="s3://bucket/handler.zip",
            )

    def test_optional_auto_publish_alias(self):
        serverless_func = Function(
            "SomeHandler",
            Handler="index.handler",
            Runtime="nodejs",
            CodeUri="s3://bucket/handler.zip",
            AutoPublishAlias="alias",
        )
        t = Template()
        t.add_resource(serverless_func)
        t.to_json()

    def test_optional_deployment_preference(self):
        serverless_func = Function(
            "SomeHandler",
            Handler="index.handler",
            Runtime="nodejs",
            CodeUri="s3://bucket/handler.zip",
            AutoPublishAlias="alias",
            DeploymentPreference=DeploymentPreference(Type="AllAtOnce"),
        )
        t = Template()
        t.add_resource(serverless_func)
        t.to_json()

    def test_required_api_definitionuri(self):
        serverless_api = Api(
            "SomeApi",
            StageName="test",
            DefinitionUri="s3://bucket/swagger.yml",
        )
        t = Template()
        t.add_resource(serverless_api)
        t.to_json()

    swagger = {
        "swagger": "2.0",
        "info": {
            "title": "swagger test",
        },
        "paths": {
            "/test": {
                "get": {},
            },
        },
    }

    def test_required_api_both(self):
        serverless_api = Api(
            "SomeApi",
            StageName="test",
            DefinitionUri="s3://bucket/swagger.yml",
            DefinitionBody=self.swagger,
        )
        t = Template()
        t.add_resource(serverless_api)
        with self.assertRaises(ValueError):
            t.to_json()

    def test_required_api_definitionbody(self):
        serverless_api = Api(
            "SomeApi",
            StageName="test",
            DefinitionBody=self.swagger,
        )
        t = Template()
        t.add_resource(serverless_api)
        t.to_json()

    def test_api_no_definition(self):
        serverless_api = Api(
            "SomeApi",
            StageName="test",
        )
        t = Template()
        t.add_resource(serverless_api)
        t.to_json()

    def test_api_auth_resource_policy(self):
        serverless_api = Api(
            title="SomeApi",
            Auth=Auth(
                ResourcePolicy=ResourcePolicyStatement(
                    AwsAccountBlacklist=["testAwsAccountBlacklist"],
                    AwsAccountWhitelist=["testAwsAccountWhitelist"],
                    CustomStatements=["testCustomStatements"],
                    IpRangeBlacklist=["testIpRangeBlacklist"],
                    IpRangeWhitelist=["testIpRangeWhitelist"],
                    SourceVpcBlacklist=["testVpcBlacklist"],
                    SourceVpcWhitelist=["testVpcWhitelist"],
                ),
            ),
            StageName="testStageName",
        )
        t = Template()
        t.add_resource(serverless_api)
        t.to_json()

    def test_api_with_endpoint_configuration(self):
        serverless_api = Api(
            title="SomeApi",
            StageName="testStageName",
            EndpointConfiguration=EndpointConfiguration(Type="PRIVATE"),
        )
        t = Template()
        t.add_resource(serverless_api)
        t.to_json()

    def test_api_with_domain(self):
        certificate = Parameter("certificate", Type="String")
        serverless_api = Api(
            "SomeApi",
            StageName="test",
            Domain=Domain(
                BasePath=["/"],
                CertificateArn=Ref(certificate),
                DomainName=Sub("subdomain.${Zone}", Zone=ImportValue("MyZone")),
                EndpointConfiguration="REGIONAL",
                Route53=Route53(
                    HostedZoneId=ImportValue("MyZone"),
                    IpV6=True,
                ),
            ),
        )
        t = Template()
        t.add_parameter(certificate)
        t.add_resource(serverless_api)
        t.to_json()

    def test_http_api_definition_uri_defined(self):
        serverless_http_api = HttpApi(
            "SomeHttpApi",
            StageName="testHttp",
            DefinitionUri="s3://bucket/swagger.yml",
        )
        t = Template()
        t.add_resource(serverless_http_api)
        t.to_json()

    def test_http_api_both_definition_uri_and_body_defined(self):
        serverless_http_api = HttpApi(
            "SomeHttpApi",
            StageName="testHttp",
            DefinitionUri="s3://bucket/swagger.yml",
            DefinitionBody=self.swagger,
        )
        t = Template()
        t.add_resource(serverless_http_api)
        with self.assertRaises(ValueError):
            t.to_json()

    def test_http_api_definition_body(self):
        serverless_http_api = HttpApi(
            "SomeHttpApi",
            StageName="testHttp",
            DefinitionBody=self.swagger,
        )
        t = Template()
        t.add_resource(serverless_http_api)
        t.to_json()

    def test_http_api_no_definition(self):
        serverless_api = HttpApi(
            "SomeHttpApi",
            StageName="testHttp",
        )
        t = Template()
        t.add_resource(serverless_api)
        t.to_json()

    def test_http_api_authorization_scopes(self):
        serverless_api = HttpApi(
            title="SomeHttpApi",
            Auth=HttpApiAuth(
                Authorizers=OAuth2Authorizer(AuthorizationScopes=["scope1", "scope2"])
            ),
            StageName="testHttpStageName",
        )
        t = Template()
        t.add_resource(serverless_api)
        t.to_json()

    def test_http_api_with_domain(self):
        certificate = Parameter("certificate", Type="String")
        serverless_http_api = HttpApi(
            "SomeHttpApi",
            StageName="testHttp",
            Domain=HttpApiDomainConfiguration(
                BasePath=["/"],
                CertificateArn=Ref(certificate),
                DomainName=Sub("subdomain.${Zone}", Zone=ImportValue("MyZone")),
                EndpointConfiguration="REGIONAL",
                Route53=Route53(
                    HostedZoneId=ImportValue("MyZone"),
                    IpV6=True,
                ),
            ),
        )
        t = Template()
        t.add_parameter(certificate)
        t.add_resource(serverless_http_api)
        t.to_json()

    def test_simple_table(self):
        serverless_table = SimpleTable("SomeTable")
        t = Template()
        t.add_resource(serverless_table)
        t.to_json()

    def test_layer_version(self):
        layer_version = LayerVersion(
            "SomeLayer",
            ContentUri="someuri",
        )
        t = Template()
        t.add_resource(layer_version)
        t.to_json()

        layer_version = LayerVersion(
            "SomeLayer",
        )
        t = Template()
        t.add_resource(layer_version)
        with self.assertRaises(ValueError):
            t.to_json()

    def test_s3_filter(self):
        t = Template()
        t.add_resource(
            Function(
                "ProcessorFunction",
                Handler="process_file.handler",
                CodeUri=".",
                Runtime="python3.6",
                Policies="AmazonS3FullAccess",
                Events={
                    "FileUpload": S3Event(
                        "FileUpload",
                        Bucket="bucket",
                        Events=["s3:ObjectCreated:*"],
                        Filter=Filter(
                            S3Key=S3Key(
                                Rules=[
                                    Rules(Name="prefix", Value="upload/"),
                                    Rules(Name="suffix", Value=".txt"),
                                ],
                            )
                        ),
                    )
                },
            )
        )
        t.to_json()

    def test_policy_document(self):
        t = Template()
        t.add_resource(
            Function(
                "ProcessorFunction",
                Handler="process_file.handler",
                CodeUri=".",
                Runtime="python3.6",
                Policies="AmazonS3ReadOnly",
            )
        )
        t.to_json()

        t = Template()
        t.add_resource(
            Function(
                "ProcessorFunction",
                Handler="process_file.handler",
                CodeUri=".",
                Runtime="python3.6",
                Policies=["AmazonS3FullAccess", "AmazonDynamoDBFullAccess"],
            )
        )
        t.to_json()

        t = Template()
        t.add_resource(
            Function(
                "ProcessorFunction",
                Handler="process_file.handler",
                CodeUri=".",
                Runtime="python3.6",
                Policies={
                    "Statement": [
                        {
                            "Effect": "Allow",
                            "Action": ["s3:GetObject", "s3:PutObject"],
                            "Resource": ["arn:aws:s3:::bucket/*"],
                        }
                    ]
                },
            )
        )
        t.to_json()

    def test_packaging(self):
        # test for no CodeUri or InlineCode
        t = Template()
        t.add_resource(
            FunctionForPackaging(
                "ProcessorFunction",
                Handler="process_file.handler",
                Runtime="python3.6",
                Policies={
                    "Statement": [
                        {
                            "Effect": "Allow",
                            "Action": ["s3:GetObject", "s3:PutObject"],
                            "Resource": ["arn:aws:s3:::bucket/*"],
                        }
                    ]
                },
            )
        )
        t.to_json()

    def test_globals(self):
        t = Template()
        t.set_transform(SERVERLESS_TRANSFORM)
        t.set_globals(
            Globals(
                Function=FunctionGlobals(),
                Api=ApiGlobals(),
                HttpApi=HttpApiGlobals(),
                SimpleTable=SimpleTableGlobals(),
            )
        )
        t.to_json()

        with self.assertRaises(AttributeError):
            Globals(Unexpected="blah")
        with self.assertRaises(TypeError):
            Globals(Function="not FunctionGlobals")

        # Assert list types are validated correctly
        FunctionGlobals(Layers=["test"])
        with self.assertRaises(TypeError):
            FunctionGlobals(Layers="not a list")
        with self.assertRaises(TypeError):
            FunctionGlobals(Layers=[1, 2, 3])

        # Assert function validators work as intended
        FunctionGlobals(MemorySize=128)
        with self.assertRaises(ValueError):
            FunctionGlobals(MemorySize=64)

    def test_api_event_auth(self):
        # Verify deprecated Auth
        api_event = ApiEvent(
            "SomeApiEvent",
            Auth=Auth(),
            Path="some path",
            Method="some method",
        )
        t = Template()
        t.add_resource(api_event)
        t.to_json()

        # Verify ApiFunctionAuth
        api_event = ApiEvent(
            "SomeApiEvent",
            Auth=ApiFunctionAuth(),
            Path="some path",
            Method="some method",
        )
        t = Template()
        t.add_resource(api_event)
        t.to_json()

        # Verify TypeError
        with self.assertRaises(TypeError):
            api_event = ApiEvent(
                "SomeApiEvent",
                Auth="some auth",
                Path="some path",
                Method="some method",
            )


if __name__ == "__main__":
    unittest.main()
